# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '/home/yeison/Documentos/Desarrollo/Pinguino/GitHub/pinguino-ide/pinguino/qtgui/frames/main.ui'
#
# Created: Tue Nov 17 17:51:44 2015
#      by: pyside-uic 0.2.15 running on PySide 1.2.4
#
# WARNING! All changes made in this file will be lost!

from PySide import QtCore, QtGui

class Ui_PinguinoIDE(object):
    def setupUi(self, PinguinoIDE):
        PinguinoIDE.setObjectName("PinguinoIDE")
        PinguinoIDE.resize(1136, 816)
        PinguinoIDE.setWindowTitle("Pinguino 12")
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/logo/art/windowIcon.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        PinguinoIDE.setWindowIcon(icon)
        PinguinoIDE.setDockOptions(QtGui.QMainWindow.AllowNestedDocks|QtGui.QMainWindow.AllowTabbedDocks|QtGui.QMainWindow.AnimatedDocks|QtGui.QMainWindow.ForceTabbedDocks)
        PinguinoIDE.setUnifiedTitleAndToolBarOnMac(True)
        self.centralwidget = QtGui.QWidget(PinguinoIDE)
        self.centralwidget.setObjectName("centralwidget")
        self.gridLayout_29 = QtGui.QGridLayout(self.centralwidget)
        self.gridLayout_29.setContentsMargins(0, 0, 0, 0)
        self.gridLayout_29.setSpacing(0)
        self.gridLayout_29.setObjectName("gridLayout_29")
        self.tabWidget_files = QtGui.QTabWidget(self.centralwidget)
        self.tabWidget_files.setTabsClosable(True)
        self.tabWidget_files.setMovable(True)
        self.tabWidget_files.setObjectName("tabWidget_files")
        self.gridLayout_29.addWidget(self.tabWidget_files, 0, 0, 1, 1)
        self.frame_logo = QtGui.QFrame(self.centralwidget)
        self.frame_logo.setFrameShape(QtGui.QFrame.NoFrame)
        self.frame_logo.setFrameShadow(QtGui.QFrame.Raised)
        self.frame_logo.setObjectName("frame_logo")
        self.gridLayout = QtGui.QGridLayout(self.frame_logo)
        self.gridLayout.setObjectName("gridLayout")
        spacerItem = QtGui.QSpacerItem(40, 20, QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
        self.gridLayout.addItem(spacerItem, 1, 0, 1, 1)
        self.label_logo = QtGui.QLabel(self.frame_logo)
        self.label_logo.setText("")
        self.label_logo.setPixmap(QtGui.QPixmap(":/logo/art/banner_blue.png"))
        self.label_logo.setObjectName("label_logo")
        self.gridLayout.addWidget(self.label_logo, 1, 1, 1, 1)
        spacerItem1 = QtGui.QSpacerItem(40, 20, QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
        self.gridLayout.addItem(spacerItem1, 1, 2, 1, 1)
        self.gridLayout_29.addWidget(self.frame_logo, 1, 0, 1, 1)
        PinguinoIDE.setCentralWidget(self.centralwidget)
        self.menubar = QtGui.QMenuBar(PinguinoIDE)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 1136, 29))
        self.menubar.setObjectName("menubar")
        self.menuFile = QtGui.QMenu(self.menubar)
        self.menuFile.setObjectName("menuFile")
        self.menuRecents = QtGui.QMenu(self.menuFile)
        self.menuRecents.setObjectName("menuRecents")
        self.menuEdit = QtGui.QMenu(self.menubar)
        self.menuEdit.setObjectName("menuEdit")
        self.menuPinguino = QtGui.QMenu(self.menubar)
        self.menuPinguino.setTitle("Debug")
        self.menuPinguino.setObjectName("menuPinguino")
        self.menuHelp = QtGui.QMenu(self.menubar)
        self.menuHelp.setObjectName("menuHelp")
        self.menuLinks = QtGui.QMenu(self.menuHelp)
        self.menuLinks.setObjectName("menuLinks")
        self.menuGitHub = QtGui.QMenu(self.menuLinks)
        self.menuGitHub.setObjectName("menuGitHub")
        self.menuSource = QtGui.QMenu(self.menubar)
        self.menuSource.setObjectName("menuSource")
        self.menuSettings = QtGui.QMenu(self.menubar)
        self.menuSettings.setObjectName("menuSettings")
        self.menuIcons_theme = QtGui.QMenu(self.menuSettings)
        self.menuIcons_theme.setObjectName("menuIcons_theme")
        self.menuIcons_size = QtGui.QMenu(self.menuSettings)
        self.menuIcons_size.setObjectName("menuIcons_size")
        self.menuProject = QtGui.QMenu(self.menubar)
        self.menuProject.setObjectName("menuProject")
        self.menuRecentProjects = QtGui.QMenu(self.menuProject)
        self.menuRecentProjects.setObjectName("menuRecentProjects")
        self.menuTools = QtGui.QMenu(self.menubar)
        self.menuTools.setObjectName("menuTools")
        PinguinoIDE.setMenuBar(self.menubar)
        self.dockWidget_right = QtGui.QDockWidget(PinguinoIDE)
        self.dockWidget_right.setFeatures(QtGui.QDockWidget.NoDockWidgetFeatures)
        self.dockWidget_right.setAllowedAreas(QtCore.Qt.LeftDockWidgetArea|QtCore.Qt.RightDockWidgetArea)
        self.dockWidget_right.setObjectName("dockWidget_right")
        self.dockWidgetContents_rigth = QtGui.QWidget()
        self.dockWidgetContents_rigth.setObjectName("dockWidgetContents_rigth")
        self.gridLayout_15 = QtGui.QGridLayout(self.dockWidgetContents_rigth)
        self.gridLayout_15.setContentsMargins(0, 0, 0, 0)
        self.gridLayout_15.setSpacing(0)
        self.gridLayout_15.setObjectName("gridLayout_15")
        self.tabWidget_tools = QtGui.QTabWidget(self.dockWidgetContents_rigth)
        self.tabWidget_tools.setAcceptDrops(True)
        self.tabWidget_tools.setTabPosition(QtGui.QTabWidget.West)
        self.tabWidget_tools.setMovable(True)
        self.tabWidget_tools.setObjectName("tabWidget_tools")
        self.Files = QtGui.QWidget()
        self.Files.setObjectName("Files")
        self.gridLayout_9 = QtGui.QGridLayout(self.Files)
        self.gridLayout_9.setObjectName("gridLayout_9")
        self.comboBox_files = QtGui.QComboBox(self.Files)
        self.comboBox_files.setObjectName("comboBox_files")
        self.comboBox_files.addItem("")
        self.comboBox_files.addItem("")
        self.comboBox_files.addItem("")
        self.comboBox_files.addItem("")
        self.gridLayout_9.addWidget(self.comboBox_files, 0, 0, 1, 1)
        self.treeWidget_explorer = QtGui.QTreeWidget(self.Files)
        self.treeWidget_explorer.setAnimated(True)
        self.treeWidget_explorer.setObjectName("treeWidget_explorer")
        self.treeWidget_explorer.headerItem().setText(0, "1")
        self.treeWidget_explorer.header().setVisible(False)
        self.gridLayout_9.addWidget(self.treeWidget_explorer, 1, 0, 1, 1)
        self.tabWidget_tools.addTab(self.Files, "")
        self.Project = QtGui.QWidget()
        self.Project.setObjectName("Project")
        self.gridLayout_16 = QtGui.QGridLayout(self.Project)
        self.gridLayout_16.setObjectName("gridLayout_16")
        self.widget_library = QtGui.QWidget(self.Project)
        self.widget_library.setObjectName("widget_library")
        self.gridLayout_28 = QtGui.QGridLayout(self.widget_library)
        self.gridLayout_28.setContentsMargins(0, -1, 0, -1)
        self.gridLayout_28.setObjectName("gridLayout_28")
        self.pushButton_compilelibrary = QtGui.QPushButton(self.widget_library)
        self.pushButton_compilelibrary.setObjectName("pushButton_compilelibrary")
        self.gridLayout_28.addWidget(self.pushButton_compilelibrary, 0, 0, 1, 1)
        self.pushButton_packagelibrary = QtGui.QPushButton(self.widget_library)
        self.pushButton_packagelibrary.setObjectName("pushButton_packagelibrary")
        self.gridLayout_28.addWidget(self.pushButton_packagelibrary, 0, 1, 1, 1)
        self.gridLayout_16.addWidget(self.widget_library, 3, 0, 1, 2)
        self.widget_noproject = QtGui.QWidget(self.Project)
        self.widget_noproject.setObjectName("widget_noproject")
        self.gridLayout_20 = QtGui.QGridLayout(self.widget_noproject)
        self.gridLayout_20.setContentsMargins(0, -1, 0, -1)
        self.gridLayout_20.setObjectName("gridLayout_20")
        self.pushButton_openproject = QtGui.QPushButton(self.widget_noproject)
        self.pushButton_openproject.setObjectName("pushButton_openproject")
        self.gridLayout_20.addWidget(self.pushButton_openproject, 4, 0, 1, 4)
        spacerItem2 = QtGui.QSpacerItem(20, 40, QtGui.QSizePolicy.Minimum, QtGui.QSizePolicy.Expanding)
        self.gridLayout_20.addItem(spacerItem2, 6, 0, 1, 4)
        spacerItem3 = QtGui.QSpacerItem(20, 60, QtGui.QSizePolicy.Minimum, QtGui.QSizePolicy.Expanding)
        self.gridLayout_20.addItem(spacerItem3, 0, 0, 1, 4)
        self.pushButton_newlibrary = QtGui.QPushButton(self.widget_noproject)
        self.pushButton_newlibrary.setObjectName("pushButton_newlibrary")
        self.gridLayout_20.addWidget(self.pushButton_newlibrary, 1, 2, 1, 2)
        self.pushButton_newproject = QtGui.QPushButton(self.widget_noproject)
        self.pushButton_newproject.setObjectName("pushButton_newproject")
        self.gridLayout_20.addWidget(self.pushButton_newproject, 1, 0, 1, 2)
        self.gridLayout_16.addWidget(self.widget_noproject, 1, 0, 1, 2)
        self.treeWidget_projects = QtGui.QTreeWidget(self.Project)
        self.treeWidget_projects.setMidLineWidth(1)
        self.treeWidget_projects.setRootIsDecorated(True)
        self.treeWidget_projects.setAnimated(True)
        self.treeWidget_projects.setColumnCount(1)
        self.treeWidget_projects.setObjectName("treeWidget_projects")
        self.treeWidget_projects.header().setDefaultSectionSize(100)
        self.treeWidget_projects.header().setSortIndicatorShown(False)
        self.treeWidget_projects.header().setStretchLastSection(True)
        self.gridLayout_16.addWidget(self.treeWidget_projects, 5, 0, 1, 2)
        self.tabWidget_tools.addTab(self.Project, "")
        self.SourceBrowser = QtGui.QWidget()
        self.SourceBrowser.setObjectName("SourceBrowser")
        self.gridLayout_25 = QtGui.QGridLayout(self.SourceBrowser)
        self.gridLayout_25.setObjectName("gridLayout_25")
        self.tabWidget_browser = QtGui.QTabWidget(self.SourceBrowser)
        self.tabWidget_browser.setTabPosition(QtGui.QTabWidget.South)
        self.tabWidget_browser.setObjectName("tabWidget_browser")
        self.Variables = QtGui.QWidget()
        self.Variables.setObjectName("Variables")
        self.gridLayout_6 = QtGui.QGridLayout(self.Variables)
        self.gridLayout_6.setContentsMargins(0, 0, 0, 0)
        self.gridLayout_6.setSpacing(0)
        self.gridLayout_6.setObjectName("gridLayout_6")
        self.tableWidget_variables = QtGui.QTableWidget(self.Variables)
        self.tableWidget_variables.setFrameShape(QtGui.QFrame.NoFrame)
        self.tableWidget_variables.setEditTriggers(QtGui.QAbstractItemView.NoEditTriggers)
        self.tableWidget_variables.setAlternatingRowColors(True)
        self.tableWidget_variables.setSelectionMode(QtGui.QAbstractItemView.NoSelection)
        self.tableWidget_variables.setHorizontalScrollMode(QtGui.QAbstractItemView.ScrollPerPixel)
        self.tableWidget_variables.setGridStyle(QtCore.Qt.NoPen)
        self.tableWidget_variables.setObjectName("tableWidget_variables")
        self.tableWidget_variables.setColumnCount(2)
        self.tableWidget_variables.setRowCount(0)
        item = QtGui.QTableWidgetItem()
        self.tableWidget_variables.setHorizontalHeaderItem(0, item)
        item = QtGui.QTableWidgetItem()
        self.tableWidget_variables.setHorizontalHeaderItem(1, item)
        self.tableWidget_variables.horizontalHeader().setStretchLastSection(True)
        self.gridLayout_6.addWidget(self.tableWidget_variables, 1, 0, 1, 1)
        self.tabWidget_browser.addTab(self.Variables, "")
        self.Functions = QtGui.QWidget()
        self.Functions.setObjectName("Functions")
        self.gridLayout_5 = QtGui.QGridLayout(self.Functions)
        self.gridLayout_5.setContentsMargins(0, 0, 0, 0)
        self.gridLayout_5.setSpacing(0)
        self.gridLayout_5.setObjectName("gridLayout_5")
        self.tableWidget_functions = QtGui.QTableWidget(self.Functions)
        self.tableWidget_functions.setFrameShape(QtGui.QFrame.NoFrame)
        self.tableWidget_functions.setEditTriggers(QtGui.QAbstractItemView.NoEditTriggers)
        self.tableWidget_functions.setAlternatingRowColors(True)
        self.tableWidget_functions.setSelectionMode(QtGui.QAbstractItemView.NoSelection)
        self.tableWidget_functions.setHorizontalScrollMode(QtGui.QAbstractItemView.ScrollPerPixel)
        self.tableWidget_functions.setShowGrid(True)
        self.tableWidget_functions.setGridStyle(QtCore.Qt.NoPen)
        self.tableWidget_functions.setObjectName("tableWidget_functions")
        self.tableWidget_functions.setColumnCount(3)
        self.tableWidget_functions.setRowCount(0)
        item = QtGui.QTableWidgetItem()
        self.tableWidget_functions.setHorizontalHeaderItem(0, item)
        item = QtGui.QTableWidgetItem()
        self.tableWidget_functions.setHorizontalHeaderItem(1, item)
        item = QtGui.QTableWidgetItem()
        self.tableWidget_functions.setHorizontalHeaderItem(2, item)
        self.tableWidget_functions.horizontalHeader().setStretchLastSection(True)
        self.gridLayout_5.addWidget(self.tableWidget_functions, 0, 0, 1, 1)
        self.tabWidget_browser.addTab(self.Functions, "")
        self.Directives = QtGui.QWidget()
        self.Directives.setObjectName("Directives")
        self.gridLayout_7 = QtGui.QGridLayout(self.Directives)
        self.gridLayout_7.setContentsMargins(0, 0, 0, 0)
        self.gridLayout_7.setSpacing(0)
        self.gridLayout_7.setObjectName("gridLayout_7")
        self.tableWidget_directives = QtGui.QTableWidget(self.Directives)
        palette = QtGui.QPalette()
        brush = QtGui.QBrush(QtGui.QColor(255, 85, 0))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.AlternateBase, brush)
        brush = QtGui.QBrush(QtGui.QColor(255, 85, 0))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.AlternateBase, brush)
        brush = QtGui.QBrush(QtGui.QColor(255, 85, 0))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.AlternateBase, brush)
        self.tableWidget_directives.setPalette(palette)
        self.tableWidget_directives.setFrameShape(QtGui.QFrame.NoFrame)
        self.tableWidget_directives.setEditTriggers(QtGui.QAbstractItemView.NoEditTriggers)
        self.tableWidget_directives.setAlternatingRowColors(True)
        self.tableWidget_directives.setSelectionMode(QtGui.QAbstractItemView.NoSelection)
        self.tableWidget_directives.setHorizontalScrollMode(QtGui.QAbstractItemView.ScrollPerPixel)
        self.tableWidget_directives.setGridStyle(QtCore.Qt.NoPen)
        self.tableWidget_directives.setObjectName("tableWidget_directives")
        self.tableWidget_directives.setColumnCount(3)
        self.tableWidget_directives.setRowCount(0)
        item = QtGui.QTableWidgetItem()
        self.tableWidget_directives.setHorizontalHeaderItem(0, item)
        item = QtGui.QTableWidgetItem()
        self.tableWidget_directives.setHorizontalHeaderItem(1, item)
        item = QtGui.QTableWidgetItem()
        self.tableWidget_directives.setHorizontalHeaderItem(2, item)
        self.tableWidget_directives.horizontalHeader().setStretchLastSection(True)
        self.gridLayout_7.addWidget(self.tableWidget_directives, 0, 0, 1, 1)
        self.tabWidget_browser.addTab(self.Directives, "")
        self.gridLayout_25.addWidget(self.tabWidget_browser, 2, 0, 1, 1)
        self.frame_source_assistnant = QtGui.QFrame(self.SourceBrowser)
        self.frame_source_assistnant.setFrameShape(QtGui.QFrame.StyledPanel)
        self.frame_source_assistnant.setFrameShadow(QtGui.QFrame.Raised)
        self.frame_source_assistnant.setObjectName("frame_source_assistnant")
        self.gridLayout_8 = QtGui.QGridLayout(self.frame_source_assistnant)
        self.gridLayout_8.setObjectName("gridLayout_8")
        self.formLayout_source_browser = QtGui.QFormLayout()
        self.formLayout_source_browser.setFieldGrowthPolicy(QtGui.QFormLayout.ExpandingFieldsGrow)
        self.formLayout_source_browser.setObjectName("formLayout_source_browser")
        self.label_name = QtGui.QLabel(self.frame_source_assistnant)
        font = QtGui.QFont()
        font.setWeight(75)
        font.setBold(True)
        self.label_name.setFont(font)
        self.label_name.setObjectName("label_name")
        self.formLayout_source_browser.setWidget(0, QtGui.QFormLayout.LabelRole, self.label_name)
        self.label_name_edit = QtGui.QLabel(self.frame_source_assistnant)
        self.label_name_edit.setText("")
        self.label_name_edit.setObjectName("label_name_edit")
        self.formLayout_source_browser.setWidget(0, QtGui.QFormLayout.FieldRole, self.label_name_edit)
        self.label_args = QtGui.QLabel(self.frame_source_assistnant)
        font = QtGui.QFont()
        font.setWeight(75)
        font.setBold(True)
        self.label_args.setFont(font)
        self.label_args.setObjectName("label_args")
        self.formLayout_source_browser.setWidget(1, QtGui.QFormLayout.LabelRole, self.label_args)
        self.label_args_edit = QtGui.QLabel(self.frame_source_assistnant)
        self.label_args_edit.setText("")
        self.label_args_edit.setObjectName("label_args_edit")
        self.formLayout_source_browser.setWidget(1, QtGui.QFormLayout.FieldRole, self.label_args_edit)
        self.label_library = QtGui.QLabel(self.frame_source_assistnant)
        font = QtGui.QFont()
        font.setWeight(75)
        font.setBold(True)
        self.label_library.setFont(font)
        self.label_library.setObjectName("label_library")
        self.formLayout_source_browser.setWidget(2, QtGui.QFormLayout.LabelRole, self.label_library)
        self.label_library_edit = QtGui.QLabel(self.frame_source_assistnant)
        self.label_library_edit.setText("")
        self.label_library_edit.setObjectName("label_library_edit")
        self.formLayout_source_browser.setWidget(2, QtGui.QFormLayout.FieldRole, self.label_library_edit)
        self.label_return = QtGui.QLabel(self.frame_source_assistnant)
        font = QtGui.QFont()
        font.setWeight(75)
        font.setBold(True)
        self.label_return.setFont(font)
        self.label_return.setObjectName("label_return")
        self.formLayout_source_browser.setWidget(3, QtGui.QFormLayout.LabelRole, self.label_return)
        self.label_return_edit = QtGui.QLabel(self.frame_source_assistnant)
        self.label_return_edit.setText("")
        self.label_return_edit.setObjectName("label_return_edit")
        self.formLayout_source_browser.setWidget(3, QtGui.QFormLayout.FieldRole, self.label_return_edit)
        self.gridLayout_8.addLayout(self.formLayout_source_browser, 0, 0, 1, 2)
        self.label_source_browser = QtGui.QLabel(self.frame_source_assistnant)
        self.label_source_browser.setStyleSheet("color: rgb(226, 0, 0);")
        self.label_source_browser.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_source_browser.setObjectName("label_source_browser")
        self.gridLayout_8.addWidget(self.label_source_browser, 1, 0, 1, 2)
        self.gridLayout_25.addWidget(self.frame_source_assistnant, 1, 0, 1, 1)
        self.tabWidget_tools.addTab(self.SourceBrowser, "")
        self.LibraryManager = QtGui.QWidget()
        self.LibraryManager.setObjectName("LibraryManager")
        self.gridLayout_30 = QtGui.QGridLayout(self.LibraryManager)
        self.gridLayout_30.setObjectName("gridLayout_30")
        self.horizontalLayout = QtGui.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.lineEdit_libraries_source = QtGui.QLineEdit(self.LibraryManager)
        self.lineEdit_libraries_source.setObjectName("lineEdit_libraries_source")
        self.horizontalLayout.addWidget(self.lineEdit_libraries_source)
        self.radioButton_library_git = QtGui.QRadioButton(self.LibraryManager)
        self.radioButton_library_git.setChecked(True)
        self.radioButton_library_git.setObjectName("radioButton_library_git")
        self.horizontalLayout.addWidget(self.radioButton_library_git)
        self.radioButton_library_mercurial = QtGui.QRadioButton(self.LibraryManager)
        self.radioButton_library_mercurial.setObjectName("radioButton_library_mercurial")
        self.horizontalLayout.addWidget(self.radioButton_library_mercurial)
        self.gridLayout_30.addLayout(self.horizontalLayout, 0, 0, 1, 1)
        self.horizontalLayout_5 = QtGui.QHBoxLayout()
        self.horizontalLayout_5.setObjectName("horizontalLayout_5")
        self.pushButton_libraries_install = QtGui.QPushButton(self.LibraryManager)
        self.pushButton_libraries_install.setObjectName("pushButton_libraries_install")
        self.horizontalLayout_5.addWidget(self.pushButton_libraries_install)
        self.pushButton_libraries_install_from_zip = QtGui.QPushButton(self.LibraryManager)
        self.pushButton_libraries_install_from_zip.setObjectName("pushButton_libraries_install_from_zip")
        self.horizontalLayout_5.addWidget(self.pushButton_libraries_install_from_zip)
        self.gridLayout_30.addLayout(self.horizontalLayout_5, 1, 0, 1, 1)
        self.tableWidget_user_libraries = QtGui.QTableWidget(self.LibraryManager)
        self.tableWidget_user_libraries.setAlternatingRowColors(True)
        self.tableWidget_user_libraries.setVerticalScrollMode(QtGui.QAbstractItemView.ScrollPerPixel)
        self.tableWidget_user_libraries.setHorizontalScrollMode(QtGui.QAbstractItemView.ScrollPerPixel)
        self.tableWidget_user_libraries.setGridStyle(QtCore.Qt.NoPen)
        self.tableWidget_user_libraries.setWordWrap(False)
        self.tableWidget_user_libraries.setCornerButtonEnabled(False)
        self.tableWidget_user_libraries.setObjectName("tableWidget_user_libraries")
        self.tableWidget_user_libraries.setColumnCount(5)
        self.tableWidget_user_libraries.setRowCount(0)
        item = QtGui.QTableWidgetItem()
        self.tableWidget_user_libraries.setHorizontalHeaderItem(0, item)
        item = QtGui.QTableWidgetItem()
        self.tableWidget_user_libraries.setHorizontalHeaderItem(1, item)
        item = QtGui.QTableWidgetItem()
        self.tableWidget_user_libraries.setHorizontalHeaderItem(2, item)
        item = QtGui.QTableWidgetItem()
        self.tableWidget_user_libraries.setHorizontalHeaderItem(3, item)
        item = QtGui.QTableWidgetItem()
        self.tableWidget_user_libraries.setHorizontalHeaderItem(4, item)
        self.tableWidget_user_libraries.horizontalHeader().setHighlightSections(False)
        self.tableWidget_user_libraries.horizontalHeader().setStretchLastSection(True)
        self.tableWidget_user_libraries.verticalHeader().setVisible(False)
        self.gridLayout_30.addWidget(self.tableWidget_user_libraries, 2, 0, 1, 1)
        self.tabWidget_tools.addTab(self.LibraryManager, "")
        self.Boards = QtGui.QWidget()
        self.Boards.setObjectName("Boards")
        self.verticalLayout = QtGui.QVBoxLayout(self.Boards)
        self.verticalLayout.setObjectName("verticalLayout")
        self.frame_arch = QtGui.QFrame(self.Boards)
        self.frame_arch.setFrameShape(QtGui.QFrame.NoFrame)
        self.frame_arch.setFrameShadow(QtGui.QFrame.Raised)
        self.frame_arch.setObjectName("frame_arch")
        self.gridLayout_22 = QtGui.QGridLayout(self.frame_arch)
        self.gridLayout_22.setObjectName("gridLayout_22")
        self.label_2 = QtGui.QLabel(self.frame_arch)
        self.label_2.setObjectName("label_2")
        self.gridLayout_22.addWidget(self.label_2, 0, 0, 1, 1)
        self.gridLayout_21 = QtGui.QGridLayout()
        self.gridLayout_21.setObjectName("gridLayout_21")
        self.radioButton_arch_8 = QtGui.QRadioButton(self.frame_arch)
        self.radioButton_arch_8.setChecked(True)
        self.radioButton_arch_8.setObjectName("radioButton_arch_8")
        self.gridLayout_21.addWidget(self.radioButton_arch_8, 0, 0, 1, 1)
        self.radioButton_arch_32 = QtGui.QRadioButton(self.frame_arch)
        self.radioButton_arch_32.setObjectName("radioButton_arch_32")
        self.gridLayout_21.addWidget(self.radioButton_arch_32, 0, 1, 1, 1)
        self.gridLayout_22.addLayout(self.gridLayout_21, 1, 0, 1, 1)
        self.line = QtGui.QFrame(self.frame_arch)
        self.line.setFrameShape(QtGui.QFrame.HLine)
        self.line.setFrameShadow(QtGui.QFrame.Sunken)
        self.line.setObjectName("line")
        self.gridLayout_22.addWidget(self.line, 2, 0, 1, 1)
        self.verticalLayout.addWidget(self.frame_arch)
        self.frame_compiler = QtGui.QFrame(self.Boards)
        self.frame_compiler.setFrameShape(QtGui.QFrame.NoFrame)
        self.frame_compiler.setFrameShadow(QtGui.QFrame.Raised)
        self.frame_compiler.setObjectName("frame_compiler")
        self.gridLayout_27 = QtGui.QGridLayout(self.frame_compiler)
        self.gridLayout_27.setObjectName("gridLayout_27")
        self.label_7 = QtGui.QLabel(self.frame_compiler)
        self.label_7.setObjectName("label_7")
        self.gridLayout_27.addWidget(self.label_7, 0, 0, 1, 1)
        self.gridLayout_26 = QtGui.QGridLayout()
        self.gridLayout_26.setObjectName("gridLayout_26")
        self.radioButton_compiler_xc8 = QtGui.QRadioButton(self.frame_compiler)
        self.radioButton_compiler_xc8.setEnabled(False)
        self.radioButton_compiler_xc8.setChecked(False)
        self.radioButton_compiler_xc8.setObjectName("radioButton_compiler_xc8")
        self.gridLayout_26.addWidget(self.radioButton_compiler_xc8, 0, 1, 1, 1)
        self.radioButton_compiler_sdcc = QtGui.QRadioButton(self.frame_compiler)
        self.radioButton_compiler_sdcc.setChecked(True)
        self.radioButton_compiler_sdcc.setObjectName("radioButton_compiler_sdcc")
        self.gridLayout_26.addWidget(self.radioButton_compiler_sdcc, 0, 0, 1, 1)
        self.gridLayout_27.addLayout(self.gridLayout_26, 1, 0, 1, 1)
        self.line_4 = QtGui.QFrame(self.frame_compiler)
        self.line_4.setFrameShape(QtGui.QFrame.HLine)
        self.line_4.setFrameShadow(QtGui.QFrame.Sunken)
        self.line_4.setObjectName("line_4")
        self.gridLayout_27.addWidget(self.line_4, 2, 0, 1, 1)
        self.verticalLayout.addWidget(self.frame_compiler)
        self.frame_prgmode = QtGui.QFrame(self.Boards)
        self.frame_prgmode.setFrameShape(QtGui.QFrame.NoFrame)
        self.frame_prgmode.setFrameShadow(QtGui.QFrame.Raised)
        self.frame_prgmode.setObjectName("frame_prgmode")
        self.gridLayout_23 = QtGui.QGridLayout(self.frame_prgmode)
        self.gridLayout_23.setObjectName("gridLayout_23")
        self.line_2 = QtGui.QFrame(self.frame_prgmode)
        self.line_2.setFrameShape(QtGui.QFrame.HLine)
        self.line_2.setFrameShadow(QtGui.QFrame.Sunken)
        self.line_2.setObjectName("line_2")
        self.gridLayout_23.addWidget(self.line_2, 2, 0, 1, 1)
        self.gridLayout_18 = QtGui.QGridLayout()
        self.gridLayout_18.setObjectName("gridLayout_18")
        self.radioButton_mode_icsp = QtGui.QRadioButton(self.frame_prgmode)
        self.radioButton_mode_icsp.setText("ICSP")
        self.radioButton_mode_icsp.setObjectName("radioButton_mode_icsp")
        self.gridLayout_18.addWidget(self.radioButton_mode_icsp, 0, 0, 1, 1)
        self.radioButton_mode_bootloader = QtGui.QRadioButton(self.frame_prgmode)
        self.radioButton_mode_bootloader.setChecked(True)
        self.radioButton_mode_bootloader.setObjectName("radioButton_mode_bootloader")
        self.gridLayout_18.addWidget(self.radioButton_mode_bootloader, 0, 1, 1, 1)
        self.gridLayout_23.addLayout(self.gridLayout_18, 1, 0, 1, 1)
        self.label = QtGui.QLabel(self.frame_prgmode)
        self.label.setObjectName("label")
        self.gridLayout_23.addWidget(self.label, 0, 0, 1, 1)
        self.verticalLayout.addWidget(self.frame_prgmode)
        self.frame_devices_8 = QtGui.QFrame(self.Boards)
        self.frame_devices_8.setFrameShape(QtGui.QFrame.NoFrame)
        self.frame_devices_8.setFrameShadow(QtGui.QFrame.Raised)
        self.frame_devices_8.setObjectName("frame_devices_8")
        self.gridLayout_3 = QtGui.QGridLayout(self.frame_devices_8)
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.gridLayout_device_8 = QtGui.QGridLayout()
        self.gridLayout_device_8.setObjectName("gridLayout_device_8")
        self.gridLayout_3.addLayout(self.gridLayout_device_8, 1, 0, 1, 1)
        self.label_4 = QtGui.QLabel(self.frame_devices_8)
        self.label_4.setObjectName("label_4")
        self.gridLayout_3.addWidget(self.label_4, 0, 0, 1, 1)
        self.verticalLayout.addWidget(self.frame_devices_8)
        self.frame_devices_32 = QtGui.QFrame(self.Boards)
        self.frame_devices_32.setFrameShape(QtGui.QFrame.NoFrame)
        self.frame_devices_32.setFrameShadow(QtGui.QFrame.Raised)
        self.frame_devices_32.setObjectName("frame_devices_32")
        self.gridLayout_14 = QtGui.QGridLayout(self.frame_devices_32)
        self.gridLayout_14.setObjectName("gridLayout_14")
        self.label_5 = QtGui.QLabel(self.frame_devices_32)
        self.label_5.setObjectName("label_5")
        self.gridLayout_14.addWidget(self.label_5, 0, 0, 1, 1)
        self.gridLayout_device_32 = QtGui.QGridLayout()
        self.gridLayout_device_32.setObjectName("gridLayout_device_32")
        self.gridLayout_14.addLayout(self.gridLayout_device_32, 1, 0, 1, 1)
        self.verticalLayout.addWidget(self.frame_devices_32)
        self.frame_advance = QtGui.QFrame(self.Boards)
        self.frame_advance.setFrameShape(QtGui.QFrame.NoFrame)
        self.frame_advance.setFrameShadow(QtGui.QFrame.Raised)
        self.frame_advance.setObjectName("frame_advance")
        self.gridLayout_17 = QtGui.QGridLayout(self.frame_advance)
        self.gridLayout_17.setObjectName("gridLayout_17")
        self.checkBox_mips16 = QtGui.QCheckBox(self.frame_advance)
        self.checkBox_mips16.setCursor(QtCore.Qt.WhatsThisCursor)
        self.checkBox_mips16.setObjectName("checkBox_mips16")
        self.gridLayout_17.addWidget(self.checkBox_mips16, 2, 0, 1, 1)
        self.label_6 = QtGui.QLabel(self.frame_advance)
        self.label_6.setObjectName("label_6")
        self.gridLayout_17.addWidget(self.label_6, 1, 0, 1, 1)
        self.horizontalLayout_7 = QtGui.QHBoxLayout()
        self.horizontalLayout_7.setObjectName("horizontalLayout_7")
        self.label_9 = QtGui.QLabel(self.frame_advance)
        self.label_9.setCursor(QtCore.Qt.WhatsThisCursor)
        self.label_9.setObjectName("label_9")
        self.horizontalLayout_7.addWidget(self.label_9)
        self.comboBox_optimization = QtGui.QComboBox(self.frame_advance)
        self.comboBox_optimization.setObjectName("comboBox_optimization")
        self.comboBox_optimization.addItem("")
        self.comboBox_optimization.addItem("")
        self.comboBox_optimization.addItem("")
        self.horizontalLayout_7.addWidget(self.comboBox_optimization)
        self.gridLayout_17.addLayout(self.horizontalLayout_7, 4, 0, 1, 1)
        self.horizontalLayout_6 = QtGui.QHBoxLayout()
        self.horizontalLayout_6.setObjectName("horizontalLayout_6")
        self.label_8 = QtGui.QLabel(self.frame_advance)
        self.label_8.setCursor(QtCore.Qt.WhatsThisCursor)
        self.label_8.setObjectName("label_8")
        self.horizontalLayout_6.addWidget(self.label_8)
        self.comboBox_heapsize = QtGui.QComboBox(self.frame_advance)
        self.comboBox_heapsize.setObjectName("comboBox_heapsize")
        self.horizontalLayout_6.addWidget(self.comboBox_heapsize)
        self.gridLayout_17.addLayout(self.horizontalLayout_6, 3, 0, 1, 1)
        self.line_5 = QtGui.QFrame(self.frame_advance)
        self.line_5.setFrameShape(QtGui.QFrame.HLine)
        self.line_5.setFrameShadow(QtGui.QFrame.Sunken)
        self.line_5.setObjectName("line_5")
        self.gridLayout_17.addWidget(self.line_5, 0, 0, 1, 1)
        self.verticalLayout.addWidget(self.frame_advance)
        spacerItem4 = QtGui.QSpacerItem(20, 40, QtGui.QSizePolicy.Minimum, QtGui.QSizePolicy.Expanding)
        self.verticalLayout.addItem(spacerItem4)
        self.tabWidget_tools.addTab(self.Boards, "")
        self.Search = QtGui.QWidget()
        self.Search.setObjectName("Search")
        self.gridLayout_10 = QtGui.QGridLayout(self.Search)
        self.gridLayout_10.setContentsMargins(-1, -1, -1, 0)
        self.gridLayout_10.setHorizontalSpacing(0)
        self.gridLayout_10.setObjectName("gridLayout_10")
        self.checkBox_case_sensitive = QtGui.QCheckBox(self.Search)
        self.checkBox_case_sensitive.setObjectName("checkBox_case_sensitive")
        self.gridLayout_10.addWidget(self.checkBox_case_sensitive, 2, 0, 1, 1)
        self.horizontalLayout_2 = QtGui.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.label_search = QtGui.QLabel(self.Search)
        self.label_search.setObjectName("label_search")
        self.horizontalLayout_2.addWidget(self.label_search)
        self.lineEdit_search = QtGui.QLineEdit(self.Search)
        self.lineEdit_search.setText("")
        self.lineEdit_search.setObjectName("lineEdit_search")
        self.horizontalLayout_2.addWidget(self.lineEdit_search)
        self.gridLayout_10.addLayout(self.horizontalLayout_2, 0, 0, 1, 1)
        self.horizontalLayout_replace = QtGui.QHBoxLayout()
        self.horizontalLayout_replace.setObjectName("horizontalLayout_replace")
        self.label_replace = QtGui.QLabel(self.Search)
        self.label_replace.setObjectName("label_replace")
        self.horizontalLayout_replace.addWidget(self.label_replace)
        self.lineEdit_replace = QtGui.QLineEdit(self.Search)
        self.lineEdit_replace.setObjectName("lineEdit_replace")
        self.horizontalLayout_replace.addWidget(self.lineEdit_replace)
        self.gridLayout_10.addLayout(self.horizontalLayout_replace, 1, 0, 1, 1)
        self.label_replace_info = QtGui.QLabel(self.Search)
        self.label_replace_info.setText("")
        self.label_replace_info.setObjectName("label_replace_info")
        self.gridLayout_10.addWidget(self.label_replace_info, 5, 0, 1, 1)
        spacerItem5 = QtGui.QSpacerItem(20, 40, QtGui.QSizePolicy.Minimum, QtGui.QSizePolicy.Expanding)
        self.gridLayout_10.addItem(spacerItem5, 6, 0, 1, 1)
        self.horizontalLayout_4 = QtGui.QHBoxLayout()
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.pushButton_search_previous = QtGui.QPushButton(self.Search)
        self.pushButton_search_previous.setEnabled(False)
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.pushButton_search_previous.setIcon(icon1)
        self.pushButton_search_previous.setObjectName("pushButton_search_previous")
        self.horizontalLayout_4.addWidget(self.pushButton_search_previous)
        self.pushButton_search_next = QtGui.QPushButton(self.Search)
        self.pushButton_search_next.setEnabled(False)
        self.pushButton_search_next.setIcon(icon1)
        self.pushButton_search_next.setObjectName("pushButton_search_next")
        self.horizontalLayout_4.addWidget(self.pushButton_search_next)
        self.pushButton_replace = QtGui.QPushButton(self.Search)
        self.pushButton_replace.setEnabled(False)
        self.pushButton_replace.setObjectName("pushButton_replace")
        self.horizontalLayout_4.addWidget(self.pushButton_replace)
        self.pushButton_replace_all = QtGui.QPushButton(self.Search)
        self.pushButton_replace_all.setEnabled(False)
        self.pushButton_replace_all.setObjectName("pushButton_replace_all")
        self.horizontalLayout_4.addWidget(self.pushButton_replace_all)
        self.gridLayout_10.addLayout(self.horizontalLayout_4, 3, 0, 1, 1)
        spacerItem6 = QtGui.QSpacerItem(20, 20, QtGui.QSizePolicy.Minimum, QtGui.QSizePolicy.Fixed)
        self.gridLayout_10.addItem(spacerItem6, 4, 0, 1, 1)
        self.tabWidget_tools.addTab(self.Search, "")
        self.Blocks = QtGui.QWidget()
        self.Blocks.setObjectName("Blocks")
        self.gridLayout_4 = QtGui.QGridLayout(self.Blocks)
        self.gridLayout_4.setObjectName("gridLayout_4")
        self.comboBox_blocks = QtGui.QComboBox(self.Blocks)
        self.comboBox_blocks.setObjectName("comboBox_blocks")
        self.gridLayout_4.addWidget(self.comboBox_blocks, 0, 0, 1, 1)
        self.stackedWidget_blocks = QtGui.QStackedWidget(self.Blocks)
        self.stackedWidget_blocks.setObjectName("stackedWidget_blocks")
        self.gridLayout_4.addWidget(self.stackedWidget_blocks, 1, 0, 1, 1)
        self.horizontalLayout_3 = QtGui.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.label_search_block = QtGui.QLabel(self.Blocks)
        self.label_search_block.setObjectName("label_search_block")
        self.horizontalLayout_3.addWidget(self.label_search_block)
        self.lineEdit_blocks_search = QtGui.QLineEdit(self.Blocks)
        self.lineEdit_blocks_search.setObjectName("lineEdit_blocks_search")
        self.horizontalLayout_3.addWidget(self.lineEdit_blocks_search)
        self.gridLayout_4.addLayout(self.horizontalLayout_3, 2, 0, 1, 1)
        self.tabWidget_tools.addTab(self.Blocks, "")
        self.gridLayout_15.addWidget(self.tabWidget_tools, 0, 1, 1, 1)
        self.dockWidget_right.setWidget(self.dockWidgetContents_rigth)
        PinguinoIDE.addDockWidget(QtCore.Qt.DockWidgetArea(2), self.dockWidget_right)
        self.toolBar = QtGui.QToolBar(PinguinoIDE)
        self.toolBar.setMovable(False)
        self.toolBar.setIconSize(QtCore.QSize(32, 32))
        self.toolBar.setObjectName("toolBar")
        PinguinoIDE.addToolBar(QtCore.Qt.TopToolBarArea, self.toolBar)
        self.statusBar = QtGui.QStatusBar(PinguinoIDE)
        self.statusBar.setObjectName("statusBar")
        PinguinoIDE.setStatusBar(self.statusBar)
        self.dockWidget_bottom = QtGui.QDockWidget(PinguinoIDE)
        self.dockWidget_bottom.setFeatures(QtGui.QDockWidget.NoDockWidgetFeatures)
        self.dockWidget_bottom.setObjectName("dockWidget_bottom")
        self.dockWidgetContents_bottom = QtGui.QWidget()
        self.dockWidgetContents_bottom.setObjectName("dockWidgetContents_bottom")
        self.gridLayout_2 = QtGui.QGridLayout(self.dockWidgetContents_bottom)
        self.gridLayout_2.setSpacing(0)
        self.gridLayout_2.setContentsMargins(0, 3, 0, 0)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.tabWidget_bottom = QtGui.QTabWidget(self.dockWidgetContents_bottom)
        self.tabWidget_bottom.setAcceptDrops(True)
        self.tabWidget_bottom.setMovable(True)
        self.tabWidget_bottom.setObjectName("tabWidget_bottom")
        self.Shell = QtGui.QWidget()
        self.Shell.setObjectName("Shell")
        self.gridLayout_11 = QtGui.QGridLayout(self.Shell)
        self.gridLayout_11.setContentsMargins(0, 0, 0, 0)
        self.gridLayout_11.setSpacing(0)
        self.gridLayout_11.setObjectName("gridLayout_11")
        self.gridLayout_shell = QtGui.QGridLayout()
        self.gridLayout_shell.setObjectName("gridLayout_shell")
        self.gridLayout_11.addLayout(self.gridLayout_shell, 0, 0, 1, 1)
        self.tabWidget_bottom.addTab(self.Shell, "")
        self.Log = QtGui.QWidget()
        self.Log.setObjectName("Log")
        self.gridLayout_12 = QtGui.QGridLayout(self.Log)
        self.gridLayout_12.setContentsMargins(0, 0, 0, 0)
        self.gridLayout_12.setSpacing(0)
        self.gridLayout_12.setObjectName("gridLayout_12")
        self.gridLayout_log = QtGui.QGridLayout()
        self.gridLayout_log.setObjectName("gridLayout_log")
        self.gridLayout_12.addLayout(self.gridLayout_log, 0, 0, 1, 1)
        self.tabWidget_bottom.addTab(self.Log, "")
        self.Stdout = QtGui.QWidget()
        self.Stdout.setObjectName("Stdout")
        self.gridLayout_13 = QtGui.QGridLayout(self.Stdout)
        self.gridLayout_13.setContentsMargins(0, 0, 0, 0)
        self.gridLayout_13.setSpacing(0)
        self.gridLayout_13.setObjectName("gridLayout_13")
        self.gridLayout_stdout = QtGui.QGridLayout()
        self.gridLayout_stdout.setObjectName("gridLayout_stdout")
        self.plainTextEdit_stdout = QtGui.QPlainTextEdit(self.Stdout)
        self.plainTextEdit_stdout.setFrameShape(QtGui.QFrame.NoFrame)
        self.plainTextEdit_stdout.setLineWrapMode(QtGui.QPlainTextEdit.NoWrap)
        self.plainTextEdit_stdout.setReadOnly(True)
        self.plainTextEdit_stdout.setObjectName("plainTextEdit_stdout")
        self.gridLayout_stdout.addWidget(self.plainTextEdit_stdout, 0, 0, 1, 1)
        self.gridLayout_13.addLayout(self.gridLayout_stdout, 0, 0, 1, 1)
        self.tabWidget_bottom.addTab(self.Stdout, "")
        self.gridLayout_2.addWidget(self.tabWidget_bottom, 0, 0, 1, 1)
        self.dockWidget_bottom.setWidget(self.dockWidgetContents_bottom)
        PinguinoIDE.addDockWidget(QtCore.Qt.DockWidgetArea(8), self.dockWidget_bottom)
        self.toolBar_menu = QtGui.QToolBar(PinguinoIDE)
        self.toolBar_menu.setMovable(False)
        self.toolBar_menu.setIconSize(QtCore.QSize(32, 32))
        self.toolBar_menu.setObjectName("toolBar_menu")
        PinguinoIDE.addToolBar(QtCore.Qt.TopToolBarArea, self.toolBar_menu)
        self.actionNew_file = QtGui.QAction(PinguinoIDE)
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap("../../../../../../../../../../../../../../../../../../pinguino-extra/resources/themes/pinguino11/icons/scalable/document-new.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionNew_file.setIcon(icon2)
        self.actionNew_file.setObjectName("actionNew_file")
        self.actionOpen_file = QtGui.QAction(PinguinoIDE)
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap("../../../../../../../../../../../../../../../../../../pinguino-extra/resources/themes/pinguino11/icons/scalable/document-open.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionOpen_file.setIcon(icon3)
        self.actionOpen_file.setObjectName("actionOpen_file")
        self.actionSave_file = QtGui.QAction(PinguinoIDE)
        self.actionSave_file.setEnabled(False)
        icon4 = QtGui.QIcon()
        icon4.addPixmap(QtGui.QPixmap("../../../../../../../../../../../../../../../../../../pinguino-extra/resources/themes/pinguino11/icons/scalable/document-save.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionSave_file.setIcon(icon4)
        self.actionSave_file.setObjectName("actionSave_file")
        self.actionClose_file = QtGui.QAction(PinguinoIDE)
        self.actionClose_file.setEnabled(False)
        self.actionClose_file.setObjectName("actionClose_file")
        self.actionUndo = QtGui.QAction(PinguinoIDE)
        self.actionUndo.setEnabled(False)
        icon5 = QtGui.QIcon()
        icon5.addPixmap(QtGui.QPixmap("../../../../../../../../../../../../../../../../../../pinguino-extra/resources/themes/pinguino11/icons/scalable/edit-undo.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionUndo.setIcon(icon5)
        self.actionUndo.setObjectName("actionUndo")
        self.actionRedo = QtGui.QAction(PinguinoIDE)
        self.actionRedo.setEnabled(False)
        icon6 = QtGui.QIcon()
        icon6.addPixmap(QtGui.QPixmap("../../../../../../../../../../../../../../../../../../pinguino-extra/resources/themes/pinguino11/icons/scalable/edit-redo.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionRedo.setIcon(icon6)
        self.actionRedo.setObjectName("actionRedo")
        self.actionCut = QtGui.QAction(PinguinoIDE)
        self.actionCut.setEnabled(False)
        icon7 = QtGui.QIcon()
        icon7.addPixmap(QtGui.QPixmap("../../../../../../../../../../../../../../../../../../pinguino-extra/resources/themes/pinguino11/icons/scalable/edit-cut.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionCut.setIcon(icon7)
        self.actionCut.setObjectName("actionCut")
        self.actionCopy = QtGui.QAction(PinguinoIDE)
        self.actionCopy.setEnabled(False)
        icon8 = QtGui.QIcon()
        icon8.addPixmap(QtGui.QPixmap("../../../../../../../../../../../../../../../../../../pinguino-extra/resources/themes/pinguino11/icons/scalable/edit-copy.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionCopy.setIcon(icon8)
        self.actionCopy.setObjectName("actionCopy")
        self.actionPaste = QtGui.QAction(PinguinoIDE)
        self.actionPaste.setEnabled(False)
        icon9 = QtGui.QIcon()
        icon9.addPixmap(QtGui.QPixmap("../../../../../../../../../../../../../../../../../../pinguino-extra/resources/themes/pinguino11/icons/scalable/edit-paste.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionPaste.setIcon(icon9)
        self.actionPaste.setObjectName("actionPaste")
        self.actionSearch = QtGui.QAction(PinguinoIDE)
        self.actionSearch.setEnabled(False)
        icon10 = QtGui.QIcon()
        icon10.addPixmap(QtGui.QPixmap("../../../../../../../../../../../../../../../../../../pinguino-extra/resources/themes/pinguino11/icons/scalable/edit-find.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionSearch.setIcon(icon10)
        self.actionSearch.setObjectName("actionSearch")
        self.actionSearch_and_replace = QtGui.QAction(PinguinoIDE)
        self.actionSearch_and_replace.setEnabled(False)
        self.actionSearch_and_replace.setIcon(icon10)
        self.actionSearch_and_replace.setObjectName("actionSearch_and_replace")
        self.actionSelect_board = QtGui.QAction(PinguinoIDE)
        icon11 = QtGui.QIcon()
        icon11.addPixmap(QtGui.QPixmap("../../../../../../../../../../../../../../../../../../pinguino-extra/resources/themes/pinguino11/icons/scalable/applications-electronics.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionSelect_board.setIcon(icon11)
        self.actionSelect_board.setObjectName("actionSelect_board")
        self.actionCompile = QtGui.QAction(PinguinoIDE)
        self.actionCompile.setEnabled(False)
        icon12 = QtGui.QIcon()
        icon12.addPixmap(QtGui.QPixmap("../../../../../../../../../../../../../../../../../../pinguino-extra/resources/themes/pinguino11/icons/scalable/system-run.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionCompile.setIcon(icon12)
        self.actionCompile.setObjectName("actionCompile")
        self.actionUpload = QtGui.QAction(PinguinoIDE)
        self.actionUpload.setEnabled(False)
        icon13 = QtGui.QIcon()
        icon13.addPixmap(QtGui.QPixmap("../../../../../../../../../../../../../../../../../../pinguino-extra/resources/themes/pinguino11/icons/scalable/emblem-downloads.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionUpload.setIcon(icon13)
        self.actionUpload.setObjectName("actionUpload")
        self.actionQuit = QtGui.QAction(PinguinoIDE)
        self.actionQuit.setObjectName("actionQuit")
        self.actionAbout = QtGui.QAction(PinguinoIDE)
        self.actionAbout.setObjectName("actionAbout")
        self.actionComment_Uncomment_region = QtGui.QAction(PinguinoIDE)
        self.actionComment_Uncomment_region.setObjectName("actionComment_Uncomment_region")
        self.actionComment_out_region = QtGui.QAction(PinguinoIDE)
        self.actionComment_out_region.setObjectName("actionComment_out_region")
        self.actionSave_image = QtGui.QAction(PinguinoIDE)
        icon14 = QtGui.QIcon()
        icon14.addPixmap(QtGui.QPixmap("../../../../../../../../../../../../../../../../../../pinguino-extra/resources/themes/pinguino11/icons/scalable/applets-screenshooter.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionSave_image.setIcon(icon14)
        self.actionSave_image.setObjectName("actionSave_image")
        self.actionSave_all = QtGui.QAction(PinguinoIDE)
        self.actionSave_all.setObjectName("actionSave_all")
        self.actionClose_all = QtGui.QAction(PinguinoIDE)
        self.actionClose_all.setObjectName("actionClose_all")
        self.actionWebsite = QtGui.QAction(PinguinoIDE)
        self.actionWebsite.setObjectName("actionWebsite")
        self.actionWiki = QtGui.QAction(PinguinoIDE)
        self.actionWiki.setObjectName("actionWiki")
        self.actionForum = QtGui.QAction(PinguinoIDE)
        self.actionForum.setObjectName("actionForum")
        self.actionBlog = QtGui.QAction(PinguinoIDE)
        self.actionBlog.setObjectName("actionBlog")
        self.actionGroup = QtGui.QAction(PinguinoIDE)
        self.actionGroup.setObjectName("actionGroup")
        self.actionShop = QtGui.QAction(PinguinoIDE)
        self.actionShop.setObjectName("actionShop")
        self.actionSave_as = QtGui.QAction(PinguinoIDE)
        self.actionSave_as.setObjectName("actionSave_as")
        self.actionAutocomplete = QtGui.QAction(PinguinoIDE)
        self.actionAutocomplete.setCheckable(True)
        self.actionAutocomplete.setChecked(True)
        self.actionAutocomplete.setObjectName("actionAutocomplete")
        self.actionColor_theme = QtGui.QAction(PinguinoIDE)
        self.actionColor_theme.setCheckable(True)
        self.actionColor_theme.setChecked(False)
        self.actionColor_theme.setObjectName("actionColor_theme")
        self.actionLibraryManager = QtGui.QAction(PinguinoIDE)
        self.actionLibraryManager.setCheckable(True)
        self.actionLibraryManager.setChecked(True)
        self.actionLibraryManager.setObjectName("actionLibraryManager")
        self.actionSet_paths = QtGui.QAction(PinguinoIDE)
        self.actionSet_paths.setObjectName("actionSet_paths")
        self.actionIndent = QtGui.QAction(PinguinoIDE)
        self.actionIndent.setObjectName("actionIndent")
        self.actionDedent = QtGui.QAction(PinguinoIDE)
        self.actionDedent.setObjectName("actionDedent")
        self.actionClose_others = QtGui.QAction(PinguinoIDE)
        self.actionClose_others.setObjectName("actionClose_others")
        self.actionDelete = QtGui.QAction(PinguinoIDE)
        self.actionDelete.setObjectName("actionDelete")
        self.actionSelect_all = QtGui.QAction(PinguinoIDE)
        self.actionSelect_all.setObjectName("actionSelect_all")
        self.actionPrint = QtGui.QAction(PinguinoIDE)
        self.actionPrint.setObjectName("actionPrint")
        self.actionToolbars = QtGui.QAction(PinguinoIDE)
        self.actionToolbars.setCheckable(True)
        self.actionToolbars.setChecked(True)
        self.actionToolbars.setObjectName("actionToolbars")
        self.actionIf_Compile_then_Upload = QtGui.QAction(PinguinoIDE)
        self.actionIf_Compile_then_Upload.setObjectName("actionIf_Compile_then_Upload")
        self.actionGitPinguinoIde = QtGui.QAction(PinguinoIDE)
        self.actionGitPinguinoIde.setObjectName("actionGitPinguinoIde")
        self.actionGitPinguinoLibraries = QtGui.QAction(PinguinoIDE)
        self.actionGitPinguinoLibraries.setObjectName("actionGitPinguinoLibraries")
        self.actionPinguino11 = QtGui.QAction(PinguinoIDE)
        self.actionPinguino11.setObjectName("actionPinguino11")
        self.action16x16 = QtGui.QAction(PinguinoIDE)
        self.action16x16.setCheckable(True)
        self.action16x16.setObjectName("action16x16")
        self.action24x24 = QtGui.QAction(PinguinoIDE)
        self.action24x24.setCheckable(True)
        self.action24x24.setObjectName("action24x24")
        self.action32x32 = QtGui.QAction(PinguinoIDE)
        self.action32x32.setCheckable(True)
        self.action32x32.setObjectName("action32x32")
        self.action48x48 = QtGui.QAction(PinguinoIDE)
        self.action48x48.setCheckable(True)
        self.action48x48.setObjectName("action48x48")
        self.actionMain_c = QtGui.QAction(PinguinoIDE)
        self.actionMain_c.setObjectName("actionMain_c")
        self.actionDefine_h = QtGui.QAction(PinguinoIDE)
        self.actionDefine_h.setObjectName("actionDefine_h")
        self.actionUser_c = QtGui.QAction(PinguinoIDE)
        self.actionUser_c.setObjectName("actionUser_c")
        self.actionUpload_hex_directly = QtGui.QAction(PinguinoIDE)
        self.actionUpload_hex_directly.setObjectName("actionUpload_hex_directly")
        self.actionMenubar = QtGui.QAction(PinguinoIDE)
        self.actionMenubar.setCheckable(True)
        self.actionMenubar.setChecked(True)
        self.actionMenubar.setObjectName("actionMenubar")
        self.actionNew_project = QtGui.QAction(PinguinoIDE)
        self.actionNew_project.setObjectName("actionNew_project")
        self.actionOpen_project = QtGui.QAction(PinguinoIDE)
        self.actionOpen_project.setObjectName("actionOpen_project")
        self.action_list_recent = QtGui.QAction(PinguinoIDE)
        self.action_list_recent.setObjectName("action_list_recent")
        self.actionSave_project = QtGui.QAction(PinguinoIDE)
        self.actionSave_project.setObjectName("actionSave_project")
        self.actionSave_project_as = QtGui.QAction(PinguinoIDE)
        self.actionSave_project_as.setObjectName("actionSave_project_as")
        self.actionClose_project = QtGui.QAction(PinguinoIDE)
        self.actionClose_project.setObjectName("actionClose_project")
        self.actionAdd_existing_directory = QtGui.QAction(PinguinoIDE)
        self.actionAdd_existing_directory.setObjectName("actionAdd_existing_directory")
        self.actionAdd_current_file = QtGui.QAction(PinguinoIDE)
        self.actionAdd_current_file.setObjectName("actionAdd_current_file")
        self.actionAdd_existing_file = QtGui.QAction(PinguinoIDE)
        self.actionAdd_existing_file.setObjectName("actionAdd_existing_file")
        self.actionAdd_new_file = QtGui.QAction(PinguinoIDE)
        self.actionAdd_new_file.setObjectName("actionAdd_new_file")
        self.actionSubmit_bug_report = QtGui.QAction(PinguinoIDE)
        self.actionSubmit_bug_report.setObjectName("actionSubmit_bug_report")
        self.actionTabShell = QtGui.QAction(PinguinoIDE)
        self.actionTabShell.setCheckable(True)
        self.actionTabShell.setChecked(True)
        self.actionTabShell.setObjectName("actionTabShell")
        self.actionTabLog = QtGui.QAction(PinguinoIDE)
        self.actionTabLog.setCheckable(True)
        self.actionTabLog.setChecked(True)
        self.actionTabLog.setObjectName("actionTabLog")
        self.actionTabStdout = QtGui.QAction(PinguinoIDE)
        self.actionTabStdout.setCheckable(True)
        self.actionTabStdout.setChecked(True)
        self.actionTabStdout.setObjectName("actionTabStdout")
        self.actionTabFiles = QtGui.QAction(PinguinoIDE)
        self.actionTabFiles.setCheckable(True)
        self.actionTabFiles.setChecked(True)
        self.actionTabFiles.setObjectName("actionTabFiles")
        self.actionTabProject = QtGui.QAction(PinguinoIDE)
        self.actionTabProject.setCheckable(True)
        self.actionTabProject.setChecked(True)
        self.actionTabProject.setObjectName("actionTabProject")
        self.actionTabSourceBrowser = QtGui.QAction(PinguinoIDE)
        self.actionTabSourceBrowser.setCheckable(True)
        self.actionTabSourceBrowser.setChecked(True)
        self.actionTabSourceBrowser.setObjectName("actionTabSourceBrowser")
        self.actionTabSearchReplace = QtGui.QAction(PinguinoIDE)
        self.actionTabSearchReplace.setCheckable(True)
        self.actionTabSearchReplace.setChecked(True)
        self.actionTabSearchReplace.setObjectName("actionTabSearchReplace")
        self.actionTabBoardConfig = QtGui.QAction(PinguinoIDE)
        self.actionTabBoardConfig.setCheckable(True)
        self.actionTabBoardConfig.setChecked(True)
        self.actionTabBoardConfig.setObjectName("actionTabBoardConfig")
        self.actionToggle_vertical_tool_area = QtGui.QAction(PinguinoIDE)
        self.actionToggle_vertical_tool_area.setObjectName("actionToggle_vertical_tool_area")
        self.actionToggle_horizontal_tool_area = QtGui.QAction(PinguinoIDE)
        self.actionToggle_horizontal_tool_area.setObjectName("actionToggle_horizontal_tool_area")
        self.actionMove_vertical_tool_area = QtGui.QAction(PinguinoIDE)
        self.actionMove_vertical_tool_area.setObjectName("actionMove_vertical_tool_area")
        self.actionPinguino_ide_manual = QtGui.QAction(PinguinoIDE)
        self.actionPinguino_ide_manual.setEnabled(True)
        self.actionPinguino_ide_manual.setObjectName("actionPinguino_ide_manual")
        self.actionLibraries_help = QtGui.QAction(PinguinoIDE)
        self.actionLibraries_help.setCheckable(False)
        self.actionLibraries_help.setEnabled(True)
        self.actionLibraries_help.setObjectName("actionLibraries_help")
        self.actionGitPinguinoCompilers = QtGui.QAction(PinguinoIDE)
        self.actionGitPinguinoCompilers.setObjectName("actionGitPinguinoCompilers")
        self.actionReset_IDE_instalation = QtGui.QAction(PinguinoIDE)
        self.actionReset_IDE_instalation.setObjectName("actionReset_IDE_instalation")
        self.actionNew_blocks_file = QtGui.QAction(PinguinoIDE)
        icon15 = QtGui.QIcon()
        icon15.addPixmap(QtGui.QPixmap("../../../../../../../../../../../../../../../../../../pinguino-extra/resources/themes/pinguino11/icons/scalable/insert-object.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionNew_blocks_file.setIcon(icon15)
        self.actionNew_blocks_file.setObjectName("actionNew_blocks_file")
        self.actionAdd_new_blocks_file = QtGui.QAction(PinguinoIDE)
        self.actionAdd_new_blocks_file.setObjectName("actionAdd_new_blocks_file")
        self.actionHex = QtGui.QAction(PinguinoIDE)
        self.actionHex.setObjectName("actionHex")
        self.actionExport_code_to_editor = QtGui.QAction(PinguinoIDE)
        self.actionExport_code_to_editor.setObjectName("actionExport_code_to_editor")
        self.actionInsert_Block = QtGui.QAction(PinguinoIDE)
        self.actionInsert_Block.setObjectName("actionInsert_Block")
        self.actionGenerate_blocks = QtGui.QAction(PinguinoIDE)
        self.actionGenerate_blocks.setObjectName("actionGenerate_blocks")
        self.actionNew_library = QtGui.QAction(PinguinoIDE)
        self.actionNew_library.setObjectName("actionNew_library")
        self.actionImport_library_project = QtGui.QAction(PinguinoIDE)
        self.actionImport_library_project.setObjectName("actionImport_library_project")
        self.action = QtGui.QAction(PinguinoIDE)
        self.action.setObjectName("action")
        self.menuRecents.addSeparator()
        self.menuFile.addAction(self.actionNew_file)
        self.menuFile.addAction(self.actionNew_blocks_file)
        self.menuFile.addAction(self.actionOpen_file)
        self.menuFile.addAction(self.menuRecents.menuAction())
        self.menuFile.addSeparator()
        self.menuFile.addAction(self.actionSave_file)
        self.menuFile.addAction(self.actionSave_as)
        self.menuFile.addAction(self.actionSave_all)
        self.menuFile.addSeparator()
        self.menuFile.addAction(self.actionClose_file)
        self.menuFile.addAction(self.actionClose_all)
        self.menuFile.addAction(self.actionClose_others)
        self.menuFile.addSeparator()
        self.menuFile.addAction(self.actionPrint)
        self.menuFile.addSeparator()
        self.menuFile.addAction(self.actionQuit)
        self.menuEdit.addAction(self.actionUndo)
        self.menuEdit.addAction(self.actionRedo)
        self.menuEdit.addSeparator()
        self.menuEdit.addAction(self.actionCut)
        self.menuEdit.addAction(self.actionCopy)
        self.menuEdit.addAction(self.actionPaste)
        self.menuEdit.addAction(self.actionDelete)
        self.menuEdit.addAction(self.actionSelect_all)
        self.menuEdit.addSeparator()
        self.menuEdit.addAction(self.actionSearch)
        self.menuEdit.addAction(self.actionSearch_and_replace)
        self.menuEdit.addSeparator()
        self.menuPinguino.addAction(self.actionSelect_board)
        self.menuPinguino.addAction(self.actionSet_paths)
        self.menuPinguino.addSeparator()
        self.menuPinguino.addAction(self.actionCompile)
        self.menuPinguino.addAction(self.actionUpload)
        self.menuPinguino.addAction(self.actionUpload_hex_directly)
        self.menuPinguino.addAction(self.actionIf_Compile_then_Upload)
        self.menuPinguino.addSeparator()
        self.menuPinguino.addAction(self.actionUser_c)
        self.menuPinguino.addAction(self.actionMain_c)
        self.menuPinguino.addAction(self.actionDefine_h)
        self.menuPinguino.addAction(self.actionHex)
        self.menuGitHub.addAction(self.actionGitPinguinoIde)
        self.menuGitHub.addAction(self.actionGitPinguinoLibraries)
        self.menuGitHub.addAction(self.actionGitPinguinoCompilers)
        self.menuLinks.addAction(self.menuGitHub.menuAction())
        self.menuLinks.addAction(self.actionWebsite)
        self.menuLinks.addAction(self.actionWiki)
        self.menuLinks.addAction(self.actionForum)
        self.menuLinks.addAction(self.actionBlog)
        self.menuLinks.addAction(self.actionGroup)
        self.menuLinks.addAction(self.actionShop)
        self.menuHelp.addAction(self.actionAbout)
        self.menuHelp.addAction(self.actionSubmit_bug_report)
        self.menuHelp.addAction(self.actionPinguino_ide_manual)
        self.menuHelp.addSeparator()
        self.menuHelp.addAction(self.menuLinks.menuAction())
        self.menuSource.addAction(self.actionAutocomplete)
        self.menuSource.addAction(self.actionComment_out_region)
        self.menuSource.addAction(self.actionComment_Uncomment_region)
        self.menuSource.addAction(self.actionInsert_Block)
        self.menuSource.addSeparator()
        self.menuSource.addAction(self.actionIndent)
        self.menuSource.addAction(self.actionDedent)
        self.menuSource.addSeparator()
        self.menuSource.addAction(self.actionGenerate_blocks)
        self.menuIcons_theme.addAction(self.actionPinguino11)
        self.menuIcons_size.addAction(self.action16x16)
        self.menuIcons_size.addAction(self.action24x24)
        self.menuIcons_size.addAction(self.action32x32)
        self.menuIcons_size.addAction(self.action48x48)
        self.menuSettings.addAction(self.actionColor_theme)
        self.menuSettings.addAction(self.menuIcons_theme.menuAction())
        self.menuSettings.addAction(self.menuIcons_size.menuAction())
        self.menuSettings.addSeparator()
        self.menuSettings.addAction(self.actionReset_IDE_instalation)
        self.menuRecentProjects.addAction(self.action_list_recent)
        self.menuProject.addAction(self.actionNew_project)
        self.menuProject.addAction(self.actionNew_library)
        self.menuProject.addSeparator()
        self.menuProject.addAction(self.actionOpen_project)
        self.menuProject.addAction(self.actionImport_library_project)
        self.menuProject.addSeparator()
        self.menuProject.addAction(self.menuRecentProjects.menuAction())
        self.menuProject.addAction(self.actionSave_project)
        self.menuProject.addAction(self.actionSave_project_as)
        self.menuProject.addAction(self.actionClose_project)
        self.menuProject.addSeparator()
        self.menuProject.addAction(self.actionAdd_existing_directory)
        self.menuProject.addAction(self.actionAdd_current_file)
        self.menuProject.addAction(self.actionAdd_existing_file)
        self.menuProject.addAction(self.actionAdd_new_file)
        self.menuProject.addAction(self.actionAdd_new_blocks_file)
        self.menuTools.addAction(self.actionToggle_vertical_tool_area)
        self.menuTools.addAction(self.actionToggle_horizontal_tool_area)
        self.menuTools.addAction(self.actionMove_vertical_tool_area)
        self.menuTools.addAction(self.actionToolbars)
        self.menuTools.addAction(self.actionMenubar)
        self.menuTools.addSeparator()
        self.menuTools.addAction(self.actionTabShell)
        self.menuTools.addAction(self.actionTabLog)
        self.menuTools.addAction(self.actionTabStdout)
        self.menuTools.addAction(self.actionTabFiles)
        self.menuTools.addAction(self.actionTabProject)
        self.menuTools.addAction(self.actionTabSourceBrowser)
        self.menuTools.addAction(self.actionLibraryManager)
        self.menuTools.addAction(self.actionTabSearchReplace)
        self.menuTools.addAction(self.actionTabBoardConfig)
        self.menubar.addAction(self.menuFile.menuAction())
        self.menubar.addAction(self.menuEdit.menuAction())
        self.menubar.addAction(self.menuProject.menuAction())
        self.menubar.addAction(self.menuSettings.menuAction())
        self.menubar.addAction(self.menuSource.menuAction())
        self.menubar.addAction(self.menuPinguino.menuAction())
        self.menubar.addAction(self.menuTools.menuAction())
        self.menubar.addAction(self.menuHelp.menuAction())
        self.toolBar.addAction(self.actionNew_file)
        self.toolBar.addAction(self.actionNew_blocks_file)
        self.toolBar.addAction(self.actionOpen_file)
        self.toolBar.addAction(self.actionSave_file)
        self.toolBar.addAction(self.actionUndo)
        self.toolBar.addAction(self.actionRedo)
        self.toolBar.addAction(self.actionCut)
        self.toolBar.addAction(self.actionCopy)
        self.toolBar.addAction(self.actionPaste)
        self.toolBar.addAction(self.actionSearch)
        self.toolBar.addAction(self.actionSelect_board)
        self.toolBar.addAction(self.actionCompile)
        self.toolBar.addAction(self.actionUpload)
        self.toolBar.addAction(self.actionSave_image)

        self.retranslateUi(PinguinoIDE)
        self.tabWidget_files.setCurrentIndex(-1)
        self.tabWidget_tools.setCurrentIndex(0)
        self.tabWidget_browser.setCurrentIndex(0)
        self.tabWidget_bottom.setCurrentIndex(2)
        QtCore.QMetaObject.connectSlotsByName(PinguinoIDE)
        PinguinoIDE.setTabOrder(self.tabWidget_browser, self.comboBox_files)
        PinguinoIDE.setTabOrder(self.comboBox_files, self.tableWidget_variables)
        PinguinoIDE.setTabOrder(self.tableWidget_variables, self.tableWidget_functions)
        PinguinoIDE.setTabOrder(self.tableWidget_functions, self.tableWidget_directives)

    def retranslateUi(self, PinguinoIDE):
        self.menuFile.setTitle(QtGui.QApplication.translate("PinguinoIDE", "File", None, QtGui.QApplication.UnicodeUTF8))
        self.menuRecents.setTitle(QtGui.QApplication.translate("PinguinoIDE", "Recents", None, QtGui.QApplication.UnicodeUTF8))
        self.menuEdit.setTitle(QtGui.QApplication.translate("PinguinoIDE", "Edit", None, QtGui.QApplication.UnicodeUTF8))
        self.menuHelp.setTitle(QtGui.QApplication.translate("PinguinoIDE", "Help", None, QtGui.QApplication.UnicodeUTF8))
        self.menuLinks.setTitle(QtGui.QApplication.translate("PinguinoIDE", "Links", None, QtGui.QApplication.UnicodeUTF8))
        self.menuGitHub.setTitle(QtGui.QApplication.translate("PinguinoIDE", "GitHub", None, QtGui.QApplication.UnicodeUTF8))
        self.menuSource.setTitle(QtGui.QApplication.translate("PinguinoIDE", "Source", None, QtGui.QApplication.UnicodeUTF8))
        self.menuSettings.setTitle(QtGui.QApplication.translate("PinguinoIDE", "Settings", None, QtGui.QApplication.UnicodeUTF8))
        self.menuIcons_theme.setTitle(QtGui.QApplication.translate("PinguinoIDE", "Icons theme", None, QtGui.QApplication.UnicodeUTF8))
        self.menuIcons_size.setTitle(QtGui.QApplication.translate("PinguinoIDE", "Icons size", None, QtGui.QApplication.UnicodeUTF8))
        self.menuProject.setTitle(QtGui.QApplication.translate("PinguinoIDE", "Project", None, QtGui.QApplication.UnicodeUTF8))
        self.menuRecentProjects.setTitle(QtGui.QApplication.translate("PinguinoIDE", "Recent", None, QtGui.QApplication.UnicodeUTF8))
        self.menuTools.setTitle(QtGui.QApplication.translate("PinguinoIDE", "Tools", None, QtGui.QApplication.UnicodeUTF8))
        self.dockWidget_right.setWindowTitle(QtGui.QApplication.translate("PinguinoIDE", "Sidebar", None, QtGui.QApplication.UnicodeUTF8))
        self.comboBox_files.setItemText(0, QtGui.QApplication.translate("PinguinoIDE", "Examples", None, QtGui.QApplication.UnicodeUTF8))
        self.comboBox_files.setItemText(1, QtGui.QApplication.translate("PinguinoIDE", "Current file directory", None, QtGui.QApplication.UnicodeUTF8))
        self.comboBox_files.setItemText(2, QtGui.QApplication.translate("PinguinoIDE", "Home", None, QtGui.QApplication.UnicodeUTF8))
        self.comboBox_files.setItemText(3, QtGui.QApplication.translate("PinguinoIDE", "Other...", None, QtGui.QApplication.UnicodeUTF8))
        self.tabWidget_tools.setTabText(self.tabWidget_tools.indexOf(self.Files), QtGui.QApplication.translate("PinguinoIDE", "Files", None, QtGui.QApplication.UnicodeUTF8))
        self.pushButton_compilelibrary.setText(QtGui.QApplication.translate("PinguinoIDE", "Compile library", None, QtGui.QApplication.UnicodeUTF8))
        self.pushButton_packagelibrary.setText(QtGui.QApplication.translate("PinguinoIDE", "Package library", None, QtGui.QApplication.UnicodeUTF8))
        self.pushButton_openproject.setText(QtGui.QApplication.translate("PinguinoIDE", "Open project", None, QtGui.QApplication.UnicodeUTF8))
        self.pushButton_newlibrary.setText(QtGui.QApplication.translate("PinguinoIDE", "New Library", None, QtGui.QApplication.UnicodeUTF8))
        self.pushButton_newproject.setText(QtGui.QApplication.translate("PinguinoIDE", "New project", None, QtGui.QApplication.UnicodeUTF8))
        self.treeWidget_projects.setSortingEnabled(False)
        self.tabWidget_tools.setTabText(self.tabWidget_tools.indexOf(self.Project), QtGui.QApplication.translate("PinguinoIDE", "Project", None, QtGui.QApplication.UnicodeUTF8))
        self.tableWidget_variables.horizontalHeaderItem(0).setText(QtGui.QApplication.translate("PinguinoIDE", "File", None, QtGui.QApplication.UnicodeUTF8))
        self.tableWidget_variables.horizontalHeaderItem(1).setText(QtGui.QApplication.translate("PinguinoIDE", "Type", None, QtGui.QApplication.UnicodeUTF8))
        self.tabWidget_browser.setTabText(self.tabWidget_browser.indexOf(self.Variables), QtGui.QApplication.translate("PinguinoIDE", "Variables", None, QtGui.QApplication.UnicodeUTF8))
        self.tableWidget_functions.horizontalHeaderItem(0).setText(QtGui.QApplication.translate("PinguinoIDE", "File", None, QtGui.QApplication.UnicodeUTF8))
        self.tableWidget_functions.horizontalHeaderItem(1).setText(QtGui.QApplication.translate("PinguinoIDE", "Return", None, QtGui.QApplication.UnicodeUTF8))
        self.tableWidget_functions.horizontalHeaderItem(2).setText(QtGui.QApplication.translate("PinguinoIDE", "Args", None, QtGui.QApplication.UnicodeUTF8))
        self.tabWidget_browser.setTabText(self.tabWidget_browser.indexOf(self.Functions), QtGui.QApplication.translate("PinguinoIDE", "Functions", None, QtGui.QApplication.UnicodeUTF8))
        self.tableWidget_directives.horizontalHeaderItem(0).setText(QtGui.QApplication.translate("PinguinoIDE", "File", None, QtGui.QApplication.UnicodeUTF8))
        self.tableWidget_directives.horizontalHeaderItem(1).setText(QtGui.QApplication.translate("PinguinoIDE", "Type", None, QtGui.QApplication.UnicodeUTF8))
        self.tableWidget_directives.horizontalHeaderItem(2).setText(QtGui.QApplication.translate("PinguinoIDE", "Value", None, QtGui.QApplication.UnicodeUTF8))
        self.tabWidget_browser.setTabText(self.tabWidget_browser.indexOf(self.Directives), QtGui.QApplication.translate("PinguinoIDE", "Directives", None, QtGui.QApplication.UnicodeUTF8))
        self.label_name.setText(QtGui.QApplication.translate("PinguinoIDE", "Name:", None, QtGui.QApplication.UnicodeUTF8))
        self.label_args.setText(QtGui.QApplication.translate("PinguinoIDE", "Args:", None, QtGui.QApplication.UnicodeUTF8))
        self.label_library.setText(QtGui.QApplication.translate("PinguinoIDE", "Library:", None, QtGui.QApplication.UnicodeUTF8))
        self.label_return.setText(QtGui.QApplication.translate("PinguinoIDE", "Retutn:", None, QtGui.QApplication.UnicodeUTF8))
        self.label_source_browser.setText(QtGui.QApplication.translate("PinguinoIDE", "Move cursor over function to see details about it.", None, QtGui.QApplication.UnicodeUTF8))
        self.tabWidget_tools.setTabText(self.tabWidget_tools.indexOf(self.SourceBrowser), QtGui.QApplication.translate("PinguinoIDE", "Source Browser", None, QtGui.QApplication.UnicodeUTF8))
        self.radioButton_library_git.setText(QtGui.QApplication.translate("PinguinoIDE", "Git", None, QtGui.QApplication.UnicodeUTF8))
        self.radioButton_library_mercurial.setText(QtGui.QApplication.translate("PinguinoIDE", "Mercurial", None, QtGui.QApplication.UnicodeUTF8))
        self.pushButton_libraries_install.setText(QtGui.QApplication.translate("PinguinoIDE", "Install", None, QtGui.QApplication.UnicodeUTF8))
        self.pushButton_libraries_install_from_zip.setText(QtGui.QApplication.translate("PinguinoIDE", "Install from .zip", None, QtGui.QApplication.UnicodeUTF8))
        self.tableWidget_user_libraries.horizontalHeaderItem(0).setText(QtGui.QApplication.translate("PinguinoIDE", "Library", None, QtGui.QApplication.UnicodeUTF8))
        self.tableWidget_user_libraries.horizontalHeaderItem(1).setText(QtGui.QApplication.translate("PinguinoIDE", "Architecture", None, QtGui.QApplication.UnicodeUTF8))
        self.tableWidget_user_libraries.horizontalHeaderItem(2).setText(QtGui.QApplication.translate("PinguinoIDE", "Author", None, QtGui.QApplication.UnicodeUTF8))
        self.tableWidget_user_libraries.horizontalHeaderItem(3).setText(QtGui.QApplication.translate("PinguinoIDE", "Info", None, QtGui.QApplication.UnicodeUTF8))
        self.tableWidget_user_libraries.horizontalHeaderItem(4).setText(QtGui.QApplication.translate("PinguinoIDE", "Remove", None, QtGui.QApplication.UnicodeUTF8))
        self.tabWidget_tools.setTabText(self.tabWidget_tools.indexOf(self.LibraryManager), QtGui.QApplication.translate("PinguinoIDE", "Library Manager", None, QtGui.QApplication.UnicodeUTF8))
        self.label_2.setText(QtGui.QApplication.translate("PinguinoIDE", "Architecture:", None, QtGui.QApplication.UnicodeUTF8))
        self.radioButton_arch_8.setText(QtGui.QApplication.translate("PinguinoIDE", "8-bit", None, QtGui.QApplication.UnicodeUTF8))
        self.radioButton_arch_32.setText(QtGui.QApplication.translate("PinguinoIDE", "32-bit", None, QtGui.QApplication.UnicodeUTF8))
        self.label_7.setText(QtGui.QApplication.translate("PinguinoIDE", "Compiler", None, QtGui.QApplication.UnicodeUTF8))
        self.radioButton_compiler_xc8.setText(QtGui.QApplication.translate("PinguinoIDE", "XC8", None, QtGui.QApplication.UnicodeUTF8))
        self.radioButton_compiler_sdcc.setText(QtGui.QApplication.translate("PinguinoIDE", "SDCC", None, QtGui.QApplication.UnicodeUTF8))
        self.radioButton_mode_bootloader.setText(QtGui.QApplication.translate("PinguinoIDE", "Bootloader", None, QtGui.QApplication.UnicodeUTF8))
        self.label.setText(QtGui.QApplication.translate("PinguinoIDE", "Programming mode:", None, QtGui.QApplication.UnicodeUTF8))
        self.label_4.setText(QtGui.QApplication.translate("PinguinoIDE", "Boards:", None, QtGui.QApplication.UnicodeUTF8))
        self.label_5.setText(QtGui.QApplication.translate("PinguinoIDE", "Boards:", None, QtGui.QApplication.UnicodeUTF8))
        self.checkBox_mips16.setToolTip(QtGui.QApplication.translate("PinguinoIDE", "<html><head/><body><p>Checked: Less memory but also less speed.<br>Unchecked: More memory but also increase speed.</p></body></html>", None, QtGui.QApplication.UnicodeUTF8))
        self.checkBox_mips16.setText(QtGui.QApplication.translate("PinguinoIDE", "Mips16", None, QtGui.QApplication.UnicodeUTF8))
        self.label_6.setText(QtGui.QApplication.translate("PinguinoIDE", "Advance options:", None, QtGui.QApplication.UnicodeUTF8))
        self.label_9.setToolTip(QtGui.QApplication.translate("PinguinoIDE", "<html><head/><body><p>-O2: The compiler will attempt to increase code performance without compromising on size, and without taking too much compilation time.</p><p>-O3: This is the highest level of optimization possible. It enables optimizations that are expensive in terms of compile time and memory usage, in many cases can slow down a system due to larger binaries and increased memory usage.</p><p>-Os: This option will optimize your code for size.</p></body></html>", None, QtGui.QApplication.UnicodeUTF8))
        self.label_9.setText(QtGui.QApplication.translate("PinguinoIDE", "Optimization:", None, QtGui.QApplication.UnicodeUTF8))
        self.comboBox_optimization.setItemText(0, QtGui.QApplication.translate("PinguinoIDE", "-O2", None, QtGui.QApplication.UnicodeUTF8))
        self.comboBox_optimization.setItemText(1, QtGui.QApplication.translate("PinguinoIDE", "-O3", None, QtGui.QApplication.UnicodeUTF8))
        self.comboBox_optimization.setItemText(2, QtGui.QApplication.translate("PinguinoIDE", "-Os", None, QtGui.QApplication.UnicodeUTF8))
        self.label_8.setToolTip(QtGui.QApplication.translate("PinguinoIDE", "<html><head/><body><p>The amount of memory allocated to objects that are being defined.</p></body></html>", None, QtGui.QApplication.UnicodeUTF8))
        self.label_8.setText(QtGui.QApplication.translate("PinguinoIDE", "Heap Size:", None, QtGui.QApplication.UnicodeUTF8))
        self.tabWidget_tools.setTabText(self.tabWidget_tools.indexOf(self.Boards), QtGui.QApplication.translate("PinguinoIDE", "Boards", None, QtGui.QApplication.UnicodeUTF8))
        self.checkBox_case_sensitive.setText(QtGui.QApplication.translate("PinguinoIDE", "Case sensitive", None, QtGui.QApplication.UnicodeUTF8))
        self.label_search.setText(QtGui.QApplication.translate("PinguinoIDE", "Search:", None, QtGui.QApplication.UnicodeUTF8))
        self.label_replace.setText(QtGui.QApplication.translate("PinguinoIDE", "Replace:", None, QtGui.QApplication.UnicodeUTF8))
        self.pushButton_search_previous.setText(QtGui.QApplication.translate("PinguinoIDE", "Previous", None, QtGui.QApplication.UnicodeUTF8))
        self.pushButton_search_next.setText(QtGui.QApplication.translate("PinguinoIDE", "Next", None, QtGui.QApplication.UnicodeUTF8))
        self.pushButton_replace.setText(QtGui.QApplication.translate("PinguinoIDE", "Replace", None, QtGui.QApplication.UnicodeUTF8))
        self.pushButton_replace_all.setText(QtGui.QApplication.translate("PinguinoIDE", "Replace all", None, QtGui.QApplication.UnicodeUTF8))
        self.tabWidget_tools.setTabText(self.tabWidget_tools.indexOf(self.Search), QtGui.QApplication.translate("PinguinoIDE", "Search", None, QtGui.QApplication.UnicodeUTF8))
        self.label_search_block.setText(QtGui.QApplication.translate("PinguinoIDE", "Search block:", None, QtGui.QApplication.UnicodeUTF8))
        self.tabWidget_tools.setTabText(self.tabWidget_tools.indexOf(self.Blocks), QtGui.QApplication.translate("PinguinoIDE", "Blocks", None, QtGui.QApplication.UnicodeUTF8))
        self.toolBar.setWindowTitle(QtGui.QApplication.translate("PinguinoIDE", "Toolbar", None, QtGui.QApplication.UnicodeUTF8))
        self.dockWidget_bottom.setWindowTitle(QtGui.QApplication.translate("PinguinoIDE", "Bottombar", None, QtGui.QApplication.UnicodeUTF8))
        self.tabWidget_bottom.setTabText(self.tabWidget_bottom.indexOf(self.Shell), QtGui.QApplication.translate("PinguinoIDE", "Python Shell", None, QtGui.QApplication.UnicodeUTF8))
        self.tabWidget_bottom.setTabText(self.tabWidget_bottom.indexOf(self.Log), QtGui.QApplication.translate("PinguinoIDE", "Log", None, QtGui.QApplication.UnicodeUTF8))
        self.tabWidget_bottom.setTabText(self.tabWidget_bottom.indexOf(self.Stdout), QtGui.QApplication.translate("PinguinoIDE", "Stdout", None, QtGui.QApplication.UnicodeUTF8))
        self.toolBar_menu.setWindowTitle(QtGui.QApplication.translate("PinguinoIDE", "Toolbar Menu", None, QtGui.QApplication.UnicodeUTF8))
        self.actionNew_file.setText(QtGui.QApplication.translate("PinguinoIDE", "New file", None, QtGui.QApplication.UnicodeUTF8))
        self.actionNew_file.setShortcut(QtGui.QApplication.translate("PinguinoIDE", "Ctrl+N", None, QtGui.QApplication.UnicodeUTF8))
        self.actionOpen_file.setText(QtGui.QApplication.translate("PinguinoIDE", "Open...", None, QtGui.QApplication.UnicodeUTF8))
        self.actionOpen_file.setShortcut(QtGui.QApplication.translate("PinguinoIDE", "Ctrl+O", None, QtGui.QApplication.UnicodeUTF8))
        self.actionSave_file.setText(QtGui.QApplication.translate("PinguinoIDE", "Save", None, QtGui.QApplication.UnicodeUTF8))
        self.actionSave_file.setShortcut(QtGui.QApplication.translate("PinguinoIDE", "Ctrl+S", None, QtGui.QApplication.UnicodeUTF8))
        self.actionClose_file.setText(QtGui.QApplication.translate("PinguinoIDE", "Close", None, QtGui.QApplication.UnicodeUTF8))
        self.actionClose_file.setToolTip(QtGui.QApplication.translate("PinguinoIDE", "Close file", None, QtGui.QApplication.UnicodeUTF8))
        self.actionClose_file.setShortcut(QtGui.QApplication.translate("PinguinoIDE", "Ctrl+W", None, QtGui.QApplication.UnicodeUTF8))
        self.actionUndo.setText(QtGui.QApplication.translate("PinguinoIDE", "Undo", None, QtGui.QApplication.UnicodeUTF8))
        self.actionUndo.setShortcut(QtGui.QApplication.translate("PinguinoIDE", "Ctrl+Z", None, QtGui.QApplication.UnicodeUTF8))
        self.actionRedo.setText(QtGui.QApplication.translate("PinguinoIDE", "Redo", None, QtGui.QApplication.UnicodeUTF8))
        self.actionRedo.setShortcut(QtGui.QApplication.translate("PinguinoIDE", "Ctrl+Y", None, QtGui.QApplication.UnicodeUTF8))
        self.actionCut.setText(QtGui.QApplication.translate("PinguinoIDE", "Cut", None, QtGui.QApplication.UnicodeUTF8))
        self.actionCut.setShortcut(QtGui.QApplication.translate("PinguinoIDE", "Ctrl+X", None, QtGui.QApplication.UnicodeUTF8))
        self.actionCopy.setText(QtGui.QApplication.translate("PinguinoIDE", "Copy", None, QtGui.QApplication.UnicodeUTF8))
        self.actionCopy.setShortcut(QtGui.QApplication.translate("PinguinoIDE", "Ctrl+C", None, QtGui.QApplication.UnicodeUTF8))
        self.actionPaste.setText(QtGui.QApplication.translate("PinguinoIDE", "Paste", None, QtGui.QApplication.UnicodeUTF8))
        self.actionPaste.setShortcut(QtGui.QApplication.translate("PinguinoIDE", "Ctrl+V", None, QtGui.QApplication.UnicodeUTF8))
        self.actionSearch.setText(QtGui.QApplication.translate("PinguinoIDE", "Search", None, QtGui.QApplication.UnicodeUTF8))
        self.actionSearch.setShortcut(QtGui.QApplication.translate("PinguinoIDE", "Ctrl+F", None, QtGui.QApplication.UnicodeUTF8))
        self.actionSearch_and_replace.setText(QtGui.QApplication.translate("PinguinoIDE", "Search and replace", None, QtGui.QApplication.UnicodeUTF8))
        self.actionSearch_and_replace.setShortcut(QtGui.QApplication.translate("PinguinoIDE", "Ctrl+R", None, QtGui.QApplication.UnicodeUTF8))
        self.actionSelect_board.setText(QtGui.QApplication.translate("PinguinoIDE", "Pinguino board selection", None, QtGui.QApplication.UnicodeUTF8))
        self.actionSelect_board.setShortcut(QtGui.QApplication.translate("PinguinoIDE", "Ctrl+Shift+B", None, QtGui.QApplication.UnicodeUTF8))
        self.actionCompile.setText(QtGui.QApplication.translate("PinguinoIDE", "Compile", None, QtGui.QApplication.UnicodeUTF8))
        self.actionCompile.setShortcut(QtGui.QApplication.translate("PinguinoIDE", "F5", None, QtGui.QApplication.UnicodeUTF8))
        self.actionUpload.setText(QtGui.QApplication.translate("PinguinoIDE", "Upload", None, QtGui.QApplication.UnicodeUTF8))
        self.actionUpload.setShortcut(QtGui.QApplication.translate("PinguinoIDE", "F6", None, QtGui.QApplication.UnicodeUTF8))
        self.actionQuit.setText(QtGui.QApplication.translate("PinguinoIDE", "Quit", None, QtGui.QApplication.UnicodeUTF8))
        self.actionQuit.setShortcut(QtGui.QApplication.translate("PinguinoIDE", "Ctrl+Q", None, QtGui.QApplication.UnicodeUTF8))
        self.actionAbout.setText(QtGui.QApplication.translate("PinguinoIDE", "About...", None, QtGui.QApplication.UnicodeUTF8))
        self.actionComment_Uncomment_region.setText(QtGui.QApplication.translate("PinguinoIDE", "Comment/Uncomment region", None, QtGui.QApplication.UnicodeUTF8))
        self.actionComment_Uncomment_region.setToolTip(QtGui.QApplication.translate("PinguinoIDE", "Comment/Uncomment region", None, QtGui.QApplication.UnicodeUTF8))
        self.actionComment_Uncomment_region.setShortcut(QtGui.QApplication.translate("PinguinoIDE", "Ctrl+.", None, QtGui.QApplication.UnicodeUTF8))
        self.actionComment_out_region.setText(QtGui.QApplication.translate("PinguinoIDE", "Comment out region", None, QtGui.QApplication.UnicodeUTF8))
        self.actionComment_out_region.setShortcut(QtGui.QApplication.translate("PinguinoIDE", "Ctrl+/", None, QtGui.QApplication.UnicodeUTF8))
        self.actionSave_image.setText(QtGui.QApplication.translate("PinguinoIDE", "Save image", None, QtGui.QApplication.UnicodeUTF8))
        self.actionSave_all.setText(QtGui.QApplication.translate("PinguinoIDE", "Save all", None, QtGui.QApplication.UnicodeUTF8))
        self.actionClose_all.setText(QtGui.QApplication.translate("PinguinoIDE", "Close all", None, QtGui.QApplication.UnicodeUTF8))
        self.actionWebsite.setText(QtGui.QApplication.translate("PinguinoIDE", "Website", None, QtGui.QApplication.UnicodeUTF8))
        self.actionWiki.setText(QtGui.QApplication.translate("PinguinoIDE", "Wiki", None, QtGui.QApplication.UnicodeUTF8))
        self.actionForum.setText(QtGui.QApplication.translate("PinguinoIDE", "Forum", None, QtGui.QApplication.UnicodeUTF8))
        self.actionBlog.setText(QtGui.QApplication.translate("PinguinoIDE", "Blog", None, QtGui.QApplication.UnicodeUTF8))
        self.actionGroup.setText(QtGui.QApplication.translate("PinguinoIDE", "Group", None, QtGui.QApplication.UnicodeUTF8))
        self.actionShop.setText(QtGui.QApplication.translate("PinguinoIDE", "Shop", None, QtGui.QApplication.UnicodeUTF8))
        self.actionSave_as.setText(QtGui.QApplication.translate("PinguinoIDE", "Save as...", None, QtGui.QApplication.UnicodeUTF8))
        self.actionSave_as.setShortcut(QtGui.QApplication.translate("PinguinoIDE", "Ctrl+Shift+S", None, QtGui.QApplication.UnicodeUTF8))
        self.actionAutocomplete.setText(QtGui.QApplication.translate("PinguinoIDE", "Autocomplete code", None, QtGui.QApplication.UnicodeUTF8))
        self.actionColor_theme.setText(QtGui.QApplication.translate("PinguinoIDE", "Background color", None, QtGui.QApplication.UnicodeUTF8))
        self.actionLibraryManager.setText(QtGui.QApplication.translate("PinguinoIDE", "Library manager", None, QtGui.QApplication.UnicodeUTF8))
        self.actionSet_paths.setText(QtGui.QApplication.translate("PinguinoIDE", "System paths...", None, QtGui.QApplication.UnicodeUTF8))
        self.actionSet_paths.setToolTip(QtGui.QApplication.translate("PinguinoIDE", "Set paths", None, QtGui.QApplication.UnicodeUTF8))
        self.actionSet_paths.setShortcut(QtGui.QApplication.translate("PinguinoIDE", "Ctrl+Shift+P", None, QtGui.QApplication.UnicodeUTF8))
        self.actionIndent.setText(QtGui.QApplication.translate("PinguinoIDE", "Indent", None, QtGui.QApplication.UnicodeUTF8))
        self.actionIndent.setShortcut(QtGui.QApplication.translate("PinguinoIDE", "Ctrl+>", None, QtGui.QApplication.UnicodeUTF8))
        self.actionDedent.setText(QtGui.QApplication.translate("PinguinoIDE", "Outdent", None, QtGui.QApplication.UnicodeUTF8))
        self.actionDedent.setShortcut(QtGui.QApplication.translate("PinguinoIDE", "Ctrl+<", None, QtGui.QApplication.UnicodeUTF8))
        self.actionClose_others.setText(QtGui.QApplication.translate("PinguinoIDE", "Close others", None, QtGui.QApplication.UnicodeUTF8))
        self.actionDelete.setText(QtGui.QApplication.translate("PinguinoIDE", "Delete", None, QtGui.QApplication.UnicodeUTF8))
        self.actionSelect_all.setText(QtGui.QApplication.translate("PinguinoIDE", "Select all", None, QtGui.QApplication.UnicodeUTF8))
        self.actionPrint.setText(QtGui.QApplication.translate("PinguinoIDE", "Print...", None, QtGui.QApplication.UnicodeUTF8))
        self.actionPrint.setShortcut(QtGui.QApplication.translate("PinguinoIDE", "Ctrl+P", None, QtGui.QApplication.UnicodeUTF8))
        self.actionToolbars.setText(QtGui.QApplication.translate("PinguinoIDE", "Toolbars", None, QtGui.QApplication.UnicodeUTF8))
        self.actionIf_Compile_then_Upload.setText(QtGui.QApplication.translate("PinguinoIDE", "If Compile then Upload", None, QtGui.QApplication.UnicodeUTF8))
        self.actionIf_Compile_then_Upload.setShortcut(QtGui.QApplication.translate("PinguinoIDE", "F7", None, QtGui.QApplication.UnicodeUTF8))
        self.actionGitPinguinoIde.setText(QtGui.QApplication.translate("PinguinoIDE", "pinguino-ide", None, QtGui.QApplication.UnicodeUTF8))
        self.actionGitPinguinoLibraries.setText(QtGui.QApplication.translate("PinguinoIDE", "pinguino-libraries", None, QtGui.QApplication.UnicodeUTF8))
        self.actionPinguino11.setText(QtGui.QApplication.translate("PinguinoIDE", "Pinguino11", None, QtGui.QApplication.UnicodeUTF8))
        self.action16x16.setText(QtGui.QApplication.translate("PinguinoIDE", "16 x 16", None, QtGui.QApplication.UnicodeUTF8))
        self.action24x24.setText(QtGui.QApplication.translate("PinguinoIDE", "24 x 24", None, QtGui.QApplication.UnicodeUTF8))
        self.action32x32.setText(QtGui.QApplication.translate("PinguinoIDE", "32 x 32", None, QtGui.QApplication.UnicodeUTF8))
        self.action48x48.setText(QtGui.QApplication.translate("PinguinoIDE", "48 x 48", None, QtGui.QApplication.UnicodeUTF8))
        self.actionMain_c.setText(QtGui.QApplication.translate("PinguinoIDE", "Open main.c", None, QtGui.QApplication.UnicodeUTF8))
        self.actionDefine_h.setText(QtGui.QApplication.translate("PinguinoIDE", "Open define.h", None, QtGui.QApplication.UnicodeUTF8))
        self.actionUser_c.setText(QtGui.QApplication.translate("PinguinoIDE", "Open user.c", None, QtGui.QApplication.UnicodeUTF8))
        self.actionUpload_hex_directly.setText(QtGui.QApplication.translate("PinguinoIDE", "Upload .hex...", None, QtGui.QApplication.UnicodeUTF8))
        self.actionMenubar.setText(QtGui.QApplication.translate("PinguinoIDE", "Menubar", None, QtGui.QApplication.UnicodeUTF8))
        self.actionNew_project.setText(QtGui.QApplication.translate("PinguinoIDE", "New project...", None, QtGui.QApplication.UnicodeUTF8))
        self.actionOpen_project.setText(QtGui.QApplication.translate("PinguinoIDE", "Open project...", None, QtGui.QApplication.UnicodeUTF8))
        self.action_list_recent.setText(QtGui.QApplication.translate("PinguinoIDE", "<list recent>", None, QtGui.QApplication.UnicodeUTF8))
        self.actionSave_project.setText(QtGui.QApplication.translate("PinguinoIDE", "Save project", None, QtGui.QApplication.UnicodeUTF8))
        self.actionSave_project_as.setText(QtGui.QApplication.translate("PinguinoIDE", "Save project as...", None, QtGui.QApplication.UnicodeUTF8))
        self.actionClose_project.setText(QtGui.QApplication.translate("PinguinoIDE", "Close project", None, QtGui.QApplication.UnicodeUTF8))
        self.actionAdd_existing_directory.setText(QtGui.QApplication.translate("PinguinoIDE", "Add existing directory...", None, QtGui.QApplication.UnicodeUTF8))
        self.actionAdd_current_file.setText(QtGui.QApplication.translate("PinguinoIDE", "Add current file", None, QtGui.QApplication.UnicodeUTF8))
        self.actionAdd_existing_file.setText(QtGui.QApplication.translate("PinguinoIDE", "Add existing file...", None, QtGui.QApplication.UnicodeUTF8))
        self.actionAdd_new_file.setText(QtGui.QApplication.translate("PinguinoIDE", "Add new file...", None, QtGui.QApplication.UnicodeUTF8))
        self.actionSubmit_bug_report.setText(QtGui.QApplication.translate("PinguinoIDE", "Submit bug report...", None, QtGui.QApplication.UnicodeUTF8))
        self.actionTabShell.setText(QtGui.QApplication.translate("PinguinoIDE", "Python shell", None, QtGui.QApplication.UnicodeUTF8))
        self.actionTabLog.setText(QtGui.QApplication.translate("PinguinoIDE", "Logs", None, QtGui.QApplication.UnicodeUTF8))
        self.actionTabStdout.setText(QtGui.QApplication.translate("PinguinoIDE", "Stdout", None, QtGui.QApplication.UnicodeUTF8))
        self.actionTabFiles.setText(QtGui.QApplication.translate("PinguinoIDE", "Files", None, QtGui.QApplication.UnicodeUTF8))
        self.actionTabProject.setText(QtGui.QApplication.translate("PinguinoIDE", "Projects", None, QtGui.QApplication.UnicodeUTF8))
        self.actionTabSourceBrowser.setText(QtGui.QApplication.translate("PinguinoIDE", "Source browser", None, QtGui.QApplication.UnicodeUTF8))
        self.actionTabSearchReplace.setText(QtGui.QApplication.translate("PinguinoIDE", "Search", None, QtGui.QApplication.UnicodeUTF8))
        self.actionTabBoardConfig.setText(QtGui.QApplication.translate("PinguinoIDE", "Boards", None, QtGui.QApplication.UnicodeUTF8))
        self.actionToggle_vertical_tool_area.setText(QtGui.QApplication.translate("PinguinoIDE", "Hide Vertical tool area", None, QtGui.QApplication.UnicodeUTF8))
        self.actionToggle_vertical_tool_area.setShortcut(QtGui.QApplication.translate("PinguinoIDE", "F2", None, QtGui.QApplication.UnicodeUTF8))
        self.actionToggle_horizontal_tool_area.setText(QtGui.QApplication.translate("PinguinoIDE", "Hide horizontal tool area", None, QtGui.QApplication.UnicodeUTF8))
        self.actionToggle_horizontal_tool_area.setShortcut(QtGui.QApplication.translate("PinguinoIDE", "F3", None, QtGui.QApplication.UnicodeUTF8))
        self.actionMove_vertical_tool_area.setText(QtGui.QApplication.translate("PinguinoIDE", "Move vertical tool area to right", None, QtGui.QApplication.UnicodeUTF8))
        self.actionPinguino_ide_manual.setText(QtGui.QApplication.translate("PinguinoIDE", "Pinguino IDE manual", None, QtGui.QApplication.UnicodeUTF8))
        self.actionLibraries_help.setText(QtGui.QApplication.translate("PinguinoIDE", "Libraries help", None, QtGui.QApplication.UnicodeUTF8))
        self.actionGitPinguinoCompilers.setText(QtGui.QApplication.translate("PinguinoIDE", "pinguino-compilers", None, QtGui.QApplication.UnicodeUTF8))
        self.actionReset_IDE_instalation.setText(QtGui.QApplication.translate("PinguinoIDE", "Reset IDE configuration", None, QtGui.QApplication.UnicodeUTF8))
        self.actionNew_blocks_file.setText(QtGui.QApplication.translate("PinguinoIDE", "New blocks file", None, QtGui.QApplication.UnicodeUTF8))
        self.actionNew_blocks_file.setShortcut(QtGui.QApplication.translate("PinguinoIDE", "Ctrl+Shift+N", None, QtGui.QApplication.UnicodeUTF8))
        self.actionAdd_new_blocks_file.setText(QtGui.QApplication.translate("PinguinoIDE", "Add new blocks file...", None, QtGui.QApplication.UnicodeUTF8))
        self.actionHex.setText(QtGui.QApplication.translate("PinguinoIDE", "Open .hex", None, QtGui.QApplication.UnicodeUTF8))
        self.actionExport_code_to_editor.setText(QtGui.QApplication.translate("PinguinoIDE", "Export code to editor", None, QtGui.QApplication.UnicodeUTF8))
        self.actionInsert_Block.setText(QtGui.QApplication.translate("PinguinoIDE", "Insert block", None, QtGui.QApplication.UnicodeUTF8))
        self.actionInsert_Block.setShortcut(QtGui.QApplication.translate("PinguinoIDE", "Ctrl+I", None, QtGui.QApplication.UnicodeUTF8))
        self.actionGenerate_blocks.setText(QtGui.QApplication.translate("PinguinoIDE", "Generate blocks", None, QtGui.QApplication.UnicodeUTF8))
        self.actionNew_library.setText(QtGui.QApplication.translate("PinguinoIDE", "New library...", None, QtGui.QApplication.UnicodeUTF8))
        self.actionImport_library_project.setText(QtGui.QApplication.translate("PinguinoIDE", "Import library project (PINGUINO)...", None, QtGui.QApplication.UnicodeUTF8))
        self.action.setText(QtGui.QApplication.translate("PinguinoIDE", "-_-", None, QtGui.QApplication.UnicodeUTF8))

import resources_rc
import resources_rc
